# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.field_mask_pb2 import (
    FieldMask as google___protobuf___field_mask_pb2___FieldMask,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.rpc.status_pb2 import Status as google___rpc___status_pb2___Status
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.metrics_pb2 import (
    Metrics as google___ads___googleads___v3___common___metrics_pb2___Metrics,
)
from google.ads.google_ads.v3.proto.common.segments_pb2 import (
    Segments as google___ads___googleads___v3___common___segments_pb2___Segments,
)
from google.ads.google_ads.v3.proto.enums.summary_row_setting_pb2 import (
    SummaryRowSettingEnum as google___ads___googleads___v3___enums___summary_row_setting_pb2___SummaryRowSettingEnum,
)
from google.ads.google_ads.v3.proto.resources.account_budget_pb2 import (
    AccountBudget as google___ads___googleads___v3___resources___account_budget_pb2___AccountBudget,
)
from google.ads.google_ads.v3.proto.resources.account_budget_proposal_pb2 import (
    AccountBudgetProposal as google___ads___googleads___v3___resources___account_budget_proposal_pb2___AccountBudgetProposal,
)
from google.ads.google_ads.v3.proto.resources.ad_group_ad_asset_view_pb2 import (
    AdGroupAdAssetView as google___ads___googleads___v3___resources___ad_group_ad_asset_view_pb2___AdGroupAdAssetView,
)
from google.ads.google_ads.v3.proto.resources.ad_group_ad_label_pb2 import (
    AdGroupAdLabel as google___ads___googleads___v3___resources___ad_group_ad_label_pb2___AdGroupAdLabel,
)
from google.ads.google_ads.v3.proto.resources.ad_group_ad_pb2 import (
    AdGroupAd as google___ads___googleads___v3___resources___ad_group_ad_pb2___AdGroupAd,
)
from google.ads.google_ads.v3.proto.resources.ad_group_audience_view_pb2 import (
    AdGroupAudienceView as google___ads___googleads___v3___resources___ad_group_audience_view_pb2___AdGroupAudienceView,
)
from google.ads.google_ads.v3.proto.resources.ad_group_bid_modifier_pb2 import (
    AdGroupBidModifier as google___ads___googleads___v3___resources___ad_group_bid_modifier_pb2___AdGroupBidModifier,
)
from google.ads.google_ads.v3.proto.resources.ad_group_criterion_label_pb2 import (
    AdGroupCriterionLabel as google___ads___googleads___v3___resources___ad_group_criterion_label_pb2___AdGroupCriterionLabel,
)
from google.ads.google_ads.v3.proto.resources.ad_group_criterion_pb2 import (
    AdGroupCriterion as google___ads___googleads___v3___resources___ad_group_criterion_pb2___AdGroupCriterion,
)
from google.ads.google_ads.v3.proto.resources.ad_group_criterion_simulation_pb2 import (
    AdGroupCriterionSimulation as google___ads___googleads___v3___resources___ad_group_criterion_simulation_pb2___AdGroupCriterionSimulation,
)
from google.ads.google_ads.v3.proto.resources.ad_group_extension_setting_pb2 import (
    AdGroupExtensionSetting as google___ads___googleads___v3___resources___ad_group_extension_setting_pb2___AdGroupExtensionSetting,
)
from google.ads.google_ads.v3.proto.resources.ad_group_feed_pb2 import (
    AdGroupFeed as google___ads___googleads___v3___resources___ad_group_feed_pb2___AdGroupFeed,
)
from google.ads.google_ads.v3.proto.resources.ad_group_label_pb2 import (
    AdGroupLabel as google___ads___googleads___v3___resources___ad_group_label_pb2___AdGroupLabel,
)
from google.ads.google_ads.v3.proto.resources.ad_group_pb2 import (
    AdGroup as google___ads___googleads___v3___resources___ad_group_pb2___AdGroup,
)
from google.ads.google_ads.v3.proto.resources.ad_group_simulation_pb2 import (
    AdGroupSimulation as google___ads___googleads___v3___resources___ad_group_simulation_pb2___AdGroupSimulation,
)
from google.ads.google_ads.v3.proto.resources.ad_parameter_pb2 import (
    AdParameter as google___ads___googleads___v3___resources___ad_parameter_pb2___AdParameter,
)
from google.ads.google_ads.v3.proto.resources.ad_schedule_view_pb2 import (
    AdScheduleView as google___ads___googleads___v3___resources___ad_schedule_view_pb2___AdScheduleView,
)
from google.ads.google_ads.v3.proto.resources.age_range_view_pb2 import (
    AgeRangeView as google___ads___googleads___v3___resources___age_range_view_pb2___AgeRangeView,
)
from google.ads.google_ads.v3.proto.resources.asset_pb2 import (
    Asset as google___ads___googleads___v3___resources___asset_pb2___Asset,
)
from google.ads.google_ads.v3.proto.resources.bidding_strategy_pb2 import (
    BiddingStrategy as google___ads___googleads___v3___resources___bidding_strategy_pb2___BiddingStrategy,
)
from google.ads.google_ads.v3.proto.resources.billing_setup_pb2 import (
    BillingSetup as google___ads___googleads___v3___resources___billing_setup_pb2___BillingSetup,
)
from google.ads.google_ads.v3.proto.resources.campaign_audience_view_pb2 import (
    CampaignAudienceView as google___ads___googleads___v3___resources___campaign_audience_view_pb2___CampaignAudienceView,
)
from google.ads.google_ads.v3.proto.resources.campaign_bid_modifier_pb2 import (
    CampaignBidModifier as google___ads___googleads___v3___resources___campaign_bid_modifier_pb2___CampaignBidModifier,
)
from google.ads.google_ads.v3.proto.resources.campaign_budget_pb2 import (
    CampaignBudget as google___ads___googleads___v3___resources___campaign_budget_pb2___CampaignBudget,
)
from google.ads.google_ads.v3.proto.resources.campaign_criterion_pb2 import (
    CampaignCriterion as google___ads___googleads___v3___resources___campaign_criterion_pb2___CampaignCriterion,
)
from google.ads.google_ads.v3.proto.resources.campaign_criterion_simulation_pb2 import (
    CampaignCriterionSimulation as google___ads___googleads___v3___resources___campaign_criterion_simulation_pb2___CampaignCriterionSimulation,
)
from google.ads.google_ads.v3.proto.resources.campaign_draft_pb2 import (
    CampaignDraft as google___ads___googleads___v3___resources___campaign_draft_pb2___CampaignDraft,
)
from google.ads.google_ads.v3.proto.resources.campaign_experiment_pb2 import (
    CampaignExperiment as google___ads___googleads___v3___resources___campaign_experiment_pb2___CampaignExperiment,
)
from google.ads.google_ads.v3.proto.resources.campaign_extension_setting_pb2 import (
    CampaignExtensionSetting as google___ads___googleads___v3___resources___campaign_extension_setting_pb2___CampaignExtensionSetting,
)
from google.ads.google_ads.v3.proto.resources.campaign_feed_pb2 import (
    CampaignFeed as google___ads___googleads___v3___resources___campaign_feed_pb2___CampaignFeed,
)
from google.ads.google_ads.v3.proto.resources.campaign_label_pb2 import (
    CampaignLabel as google___ads___googleads___v3___resources___campaign_label_pb2___CampaignLabel,
)
from google.ads.google_ads.v3.proto.resources.campaign_pb2 import (
    Campaign as google___ads___googleads___v3___resources___campaign_pb2___Campaign,
)
from google.ads.google_ads.v3.proto.resources.campaign_shared_set_pb2 import (
    CampaignSharedSet as google___ads___googleads___v3___resources___campaign_shared_set_pb2___CampaignSharedSet,
)
from google.ads.google_ads.v3.proto.resources.carrier_constant_pb2 import (
    CarrierConstant as google___ads___googleads___v3___resources___carrier_constant_pb2___CarrierConstant,
)
from google.ads.google_ads.v3.proto.resources.change_status_pb2 import (
    ChangeStatus as google___ads___googleads___v3___resources___change_status_pb2___ChangeStatus,
)
from google.ads.google_ads.v3.proto.resources.click_view_pb2 import (
    ClickView as google___ads___googleads___v3___resources___click_view_pb2___ClickView,
)
from google.ads.google_ads.v3.proto.resources.conversion_action_pb2 import (
    ConversionAction as google___ads___googleads___v3___resources___conversion_action_pb2___ConversionAction,
)
from google.ads.google_ads.v3.proto.resources.currency_constant_pb2 import (
    CurrencyConstant as google___ads___googleads___v3___resources___currency_constant_pb2___CurrencyConstant,
)
from google.ads.google_ads.v3.proto.resources.custom_interest_pb2 import (
    CustomInterest as google___ads___googleads___v3___resources___custom_interest_pb2___CustomInterest,
)
from google.ads.google_ads.v3.proto.resources.customer_client_link_pb2 import (
    CustomerClientLink as google___ads___googleads___v3___resources___customer_client_link_pb2___CustomerClientLink,
)
from google.ads.google_ads.v3.proto.resources.customer_client_pb2 import (
    CustomerClient as google___ads___googleads___v3___resources___customer_client_pb2___CustomerClient,
)
from google.ads.google_ads.v3.proto.resources.customer_extension_setting_pb2 import (
    CustomerExtensionSetting as google___ads___googleads___v3___resources___customer_extension_setting_pb2___CustomerExtensionSetting,
)
from google.ads.google_ads.v3.proto.resources.customer_feed_pb2 import (
    CustomerFeed as google___ads___googleads___v3___resources___customer_feed_pb2___CustomerFeed,
)
from google.ads.google_ads.v3.proto.resources.customer_label_pb2 import (
    CustomerLabel as google___ads___googleads___v3___resources___customer_label_pb2___CustomerLabel,
)
from google.ads.google_ads.v3.proto.resources.customer_manager_link_pb2 import (
    CustomerManagerLink as google___ads___googleads___v3___resources___customer_manager_link_pb2___CustomerManagerLink,
)
from google.ads.google_ads.v3.proto.resources.customer_negative_criterion_pb2 import (
    CustomerNegativeCriterion as google___ads___googleads___v3___resources___customer_negative_criterion_pb2___CustomerNegativeCriterion,
)
from google.ads.google_ads.v3.proto.resources.customer_pb2 import (
    Customer as google___ads___googleads___v3___resources___customer_pb2___Customer,
)
from google.ads.google_ads.v3.proto.resources.detail_placement_view_pb2 import (
    DetailPlacementView as google___ads___googleads___v3___resources___detail_placement_view_pb2___DetailPlacementView,
)
from google.ads.google_ads.v3.proto.resources.display_keyword_view_pb2 import (
    DisplayKeywordView as google___ads___googleads___v3___resources___display_keyword_view_pb2___DisplayKeywordView,
)
from google.ads.google_ads.v3.proto.resources.distance_view_pb2 import (
    DistanceView as google___ads___googleads___v3___resources___distance_view_pb2___DistanceView,
)
from google.ads.google_ads.v3.proto.resources.domain_category_pb2 import (
    DomainCategory as google___ads___googleads___v3___resources___domain_category_pb2___DomainCategory,
)
from google.ads.google_ads.v3.proto.resources.dynamic_search_ads_search_term_view_pb2 import (
    DynamicSearchAdsSearchTermView as google___ads___googleads___v3___resources___dynamic_search_ads_search_term_view_pb2___DynamicSearchAdsSearchTermView,
)
from google.ads.google_ads.v3.proto.resources.expanded_landing_page_view_pb2 import (
    ExpandedLandingPageView as google___ads___googleads___v3___resources___expanded_landing_page_view_pb2___ExpandedLandingPageView,
)
from google.ads.google_ads.v3.proto.resources.extension_feed_item_pb2 import (
    ExtensionFeedItem as google___ads___googleads___v3___resources___extension_feed_item_pb2___ExtensionFeedItem,
)
from google.ads.google_ads.v3.proto.resources.feed_item_pb2 import (
    FeedItem as google___ads___googleads___v3___resources___feed_item_pb2___FeedItem,
)
from google.ads.google_ads.v3.proto.resources.feed_item_target_pb2 import (
    FeedItemTarget as google___ads___googleads___v3___resources___feed_item_target_pb2___FeedItemTarget,
)
from google.ads.google_ads.v3.proto.resources.feed_mapping_pb2 import (
    FeedMapping as google___ads___googleads___v3___resources___feed_mapping_pb2___FeedMapping,
)
from google.ads.google_ads.v3.proto.resources.feed_pb2 import (
    Feed as google___ads___googleads___v3___resources___feed_pb2___Feed,
)
from google.ads.google_ads.v3.proto.resources.feed_placeholder_view_pb2 import (
    FeedPlaceholderView as google___ads___googleads___v3___resources___feed_placeholder_view_pb2___FeedPlaceholderView,
)
from google.ads.google_ads.v3.proto.resources.gender_view_pb2 import (
    GenderView as google___ads___googleads___v3___resources___gender_view_pb2___GenderView,
)
from google.ads.google_ads.v3.proto.resources.geo_target_constant_pb2 import (
    GeoTargetConstant as google___ads___googleads___v3___resources___geo_target_constant_pb2___GeoTargetConstant,
)
from google.ads.google_ads.v3.proto.resources.geographic_view_pb2 import (
    GeographicView as google___ads___googleads___v3___resources___geographic_view_pb2___GeographicView,
)
from google.ads.google_ads.v3.proto.resources.group_placement_view_pb2 import (
    GroupPlacementView as google___ads___googleads___v3___resources___group_placement_view_pb2___GroupPlacementView,
)
from google.ads.google_ads.v3.proto.resources.hotel_group_view_pb2 import (
    HotelGroupView as google___ads___googleads___v3___resources___hotel_group_view_pb2___HotelGroupView,
)
from google.ads.google_ads.v3.proto.resources.hotel_performance_view_pb2 import (
    HotelPerformanceView as google___ads___googleads___v3___resources___hotel_performance_view_pb2___HotelPerformanceView,
)
from google.ads.google_ads.v3.proto.resources.keyword_plan_ad_group_pb2 import (
    KeywordPlanAdGroup as google___ads___googleads___v3___resources___keyword_plan_ad_group_pb2___KeywordPlanAdGroup,
)
from google.ads.google_ads.v3.proto.resources.keyword_plan_campaign_pb2 import (
    KeywordPlanCampaign as google___ads___googleads___v3___resources___keyword_plan_campaign_pb2___KeywordPlanCampaign,
)
from google.ads.google_ads.v3.proto.resources.keyword_plan_keyword_pb2 import (
    KeywordPlanKeyword as google___ads___googleads___v3___resources___keyword_plan_keyword_pb2___KeywordPlanKeyword,
)
from google.ads.google_ads.v3.proto.resources.keyword_plan_negative_keyword_pb2 import (
    KeywordPlanNegativeKeyword as google___ads___googleads___v3___resources___keyword_plan_negative_keyword_pb2___KeywordPlanNegativeKeyword,
)
from google.ads.google_ads.v3.proto.resources.keyword_plan_pb2 import (
    KeywordPlan as google___ads___googleads___v3___resources___keyword_plan_pb2___KeywordPlan,
)
from google.ads.google_ads.v3.proto.resources.keyword_view_pb2 import (
    KeywordView as google___ads___googleads___v3___resources___keyword_view_pb2___KeywordView,
)
from google.ads.google_ads.v3.proto.resources.label_pb2 import (
    Label as google___ads___googleads___v3___resources___label_pb2___Label,
)
from google.ads.google_ads.v3.proto.resources.landing_page_view_pb2 import (
    LandingPageView as google___ads___googleads___v3___resources___landing_page_view_pb2___LandingPageView,
)
from google.ads.google_ads.v3.proto.resources.language_constant_pb2 import (
    LanguageConstant as google___ads___googleads___v3___resources___language_constant_pb2___LanguageConstant,
)
from google.ads.google_ads.v3.proto.resources.location_view_pb2 import (
    LocationView as google___ads___googleads___v3___resources___location_view_pb2___LocationView,
)
from google.ads.google_ads.v3.proto.resources.managed_placement_view_pb2 import (
    ManagedPlacementView as google___ads___googleads___v3___resources___managed_placement_view_pb2___ManagedPlacementView,
)
from google.ads.google_ads.v3.proto.resources.media_file_pb2 import (
    MediaFile as google___ads___googleads___v3___resources___media_file_pb2___MediaFile,
)
from google.ads.google_ads.v3.proto.resources.mobile_app_category_constant_pb2 import (
    MobileAppCategoryConstant as google___ads___googleads___v3___resources___mobile_app_category_constant_pb2___MobileAppCategoryConstant,
)
from google.ads.google_ads.v3.proto.resources.mobile_device_constant_pb2 import (
    MobileDeviceConstant as google___ads___googleads___v3___resources___mobile_device_constant_pb2___MobileDeviceConstant,
)
from google.ads.google_ads.v3.proto.resources.mutate_job_pb2 import (
    MutateJob as google___ads___googleads___v3___resources___mutate_job_pb2___MutateJob,
)
from google.ads.google_ads.v3.proto.resources.offline_user_data_job_pb2 import (
    OfflineUserDataJob as google___ads___googleads___v3___resources___offline_user_data_job_pb2___OfflineUserDataJob,
)
from google.ads.google_ads.v3.proto.resources.operating_system_version_constant_pb2 import (
    OperatingSystemVersionConstant as google___ads___googleads___v3___resources___operating_system_version_constant_pb2___OperatingSystemVersionConstant,
)
from google.ads.google_ads.v3.proto.resources.paid_organic_search_term_view_pb2 import (
    PaidOrganicSearchTermView as google___ads___googleads___v3___resources___paid_organic_search_term_view_pb2___PaidOrganicSearchTermView,
)
from google.ads.google_ads.v3.proto.resources.parental_status_view_pb2 import (
    ParentalStatusView as google___ads___googleads___v3___resources___parental_status_view_pb2___ParentalStatusView,
)
from google.ads.google_ads.v3.proto.resources.product_bidding_category_constant_pb2 import (
    ProductBiddingCategoryConstant as google___ads___googleads___v3___resources___product_bidding_category_constant_pb2___ProductBiddingCategoryConstant,
)
from google.ads.google_ads.v3.proto.resources.product_group_view_pb2 import (
    ProductGroupView as google___ads___googleads___v3___resources___product_group_view_pb2___ProductGroupView,
)
from google.ads.google_ads.v3.proto.resources.recommendation_pb2 import (
    Recommendation as google___ads___googleads___v3___resources___recommendation_pb2___Recommendation,
)
from google.ads.google_ads.v3.proto.resources.remarketing_action_pb2 import (
    RemarketingAction as google___ads___googleads___v3___resources___remarketing_action_pb2___RemarketingAction,
)
from google.ads.google_ads.v3.proto.resources.search_term_view_pb2 import (
    SearchTermView as google___ads___googleads___v3___resources___search_term_view_pb2___SearchTermView,
)
from google.ads.google_ads.v3.proto.resources.shared_criterion_pb2 import (
    SharedCriterion as google___ads___googleads___v3___resources___shared_criterion_pb2___SharedCriterion,
)
from google.ads.google_ads.v3.proto.resources.shared_set_pb2 import (
    SharedSet as google___ads___googleads___v3___resources___shared_set_pb2___SharedSet,
)
from google.ads.google_ads.v3.proto.resources.shopping_performance_view_pb2 import (
    ShoppingPerformanceView as google___ads___googleads___v3___resources___shopping_performance_view_pb2___ShoppingPerformanceView,
)
from google.ads.google_ads.v3.proto.resources.topic_constant_pb2 import (
    TopicConstant as google___ads___googleads___v3___resources___topic_constant_pb2___TopicConstant,
)
from google.ads.google_ads.v3.proto.resources.topic_view_pb2 import (
    TopicView as google___ads___googleads___v3___resources___topic_view_pb2___TopicView,
)
from google.ads.google_ads.v3.proto.resources.user_interest_pb2 import (
    UserInterest as google___ads___googleads___v3___resources___user_interest_pb2___UserInterest,
)
from google.ads.google_ads.v3.proto.resources.user_list_pb2 import (
    UserList as google___ads___googleads___v3___resources___user_list_pb2___UserList,
)
from google.ads.google_ads.v3.proto.resources.user_location_view_pb2 import (
    UserLocationView as google___ads___googleads___v3___resources___user_location_view_pb2___UserLocationView,
)
from google.ads.google_ads.v3.proto.resources.video_pb2 import (
    Video as google___ads___googleads___v3___resources___video_pb2___Video,
)
from google.ads.google_ads.v3.proto.services.ad_group_ad_label_service_pb2 import (
    AdGroupAdLabelOperation as google___ads___googleads___v3___services___ad_group_ad_label_service_pb2___AdGroupAdLabelOperation,
    MutateAdGroupAdLabelResult as google___ads___googleads___v3___services___ad_group_ad_label_service_pb2___MutateAdGroupAdLabelResult,
)
from google.ads.google_ads.v3.proto.services.ad_group_ad_service_pb2 import (
    AdGroupAdOperation as google___ads___googleads___v3___services___ad_group_ad_service_pb2___AdGroupAdOperation,
    MutateAdGroupAdResult as google___ads___googleads___v3___services___ad_group_ad_service_pb2___MutateAdGroupAdResult,
)
from google.ads.google_ads.v3.proto.services.ad_group_bid_modifier_service_pb2 import (
    AdGroupBidModifierOperation as google___ads___googleads___v3___services___ad_group_bid_modifier_service_pb2___AdGroupBidModifierOperation,
    MutateAdGroupBidModifierResult as google___ads___googleads___v3___services___ad_group_bid_modifier_service_pb2___MutateAdGroupBidModifierResult,
)
from google.ads.google_ads.v3.proto.services.ad_group_criterion_label_service_pb2 import (
    AdGroupCriterionLabelOperation as google___ads___googleads___v3___services___ad_group_criterion_label_service_pb2___AdGroupCriterionLabelOperation,
    MutateAdGroupCriterionLabelResult as google___ads___googleads___v3___services___ad_group_criterion_label_service_pb2___MutateAdGroupCriterionLabelResult,
)
from google.ads.google_ads.v3.proto.services.ad_group_criterion_service_pb2 import (
    AdGroupCriterionOperation as google___ads___googleads___v3___services___ad_group_criterion_service_pb2___AdGroupCriterionOperation,
    MutateAdGroupCriterionResult as google___ads___googleads___v3___services___ad_group_criterion_service_pb2___MutateAdGroupCriterionResult,
)
from google.ads.google_ads.v3.proto.services.ad_group_extension_setting_service_pb2 import (
    AdGroupExtensionSettingOperation as google___ads___googleads___v3___services___ad_group_extension_setting_service_pb2___AdGroupExtensionSettingOperation,
    MutateAdGroupExtensionSettingResult as google___ads___googleads___v3___services___ad_group_extension_setting_service_pb2___MutateAdGroupExtensionSettingResult,
)
from google.ads.google_ads.v3.proto.services.ad_group_feed_service_pb2 import (
    AdGroupFeedOperation as google___ads___googleads___v3___services___ad_group_feed_service_pb2___AdGroupFeedOperation,
    MutateAdGroupFeedResult as google___ads___googleads___v3___services___ad_group_feed_service_pb2___MutateAdGroupFeedResult,
)
from google.ads.google_ads.v3.proto.services.ad_group_label_service_pb2 import (
    AdGroupLabelOperation as google___ads___googleads___v3___services___ad_group_label_service_pb2___AdGroupLabelOperation,
    MutateAdGroupLabelResult as google___ads___googleads___v3___services___ad_group_label_service_pb2___MutateAdGroupLabelResult,
)
from google.ads.google_ads.v3.proto.services.ad_group_service_pb2 import (
    AdGroupOperation as google___ads___googleads___v3___services___ad_group_service_pb2___AdGroupOperation,
    MutateAdGroupResult as google___ads___googleads___v3___services___ad_group_service_pb2___MutateAdGroupResult,
)
from google.ads.google_ads.v3.proto.services.ad_parameter_service_pb2 import (
    AdParameterOperation as google___ads___googleads___v3___services___ad_parameter_service_pb2___AdParameterOperation,
    MutateAdParameterResult as google___ads___googleads___v3___services___ad_parameter_service_pb2___MutateAdParameterResult,
)
from google.ads.google_ads.v3.proto.services.ad_service_pb2 import (
    AdOperation as google___ads___googleads___v3___services___ad_service_pb2___AdOperation,
    MutateAdResult as google___ads___googleads___v3___services___ad_service_pb2___MutateAdResult,
)
from google.ads.google_ads.v3.proto.services.asset_service_pb2 import (
    AssetOperation as google___ads___googleads___v3___services___asset_service_pb2___AssetOperation,
    MutateAssetResult as google___ads___googleads___v3___services___asset_service_pb2___MutateAssetResult,
)
from google.ads.google_ads.v3.proto.services.bidding_strategy_service_pb2 import (
    BiddingStrategyOperation as google___ads___googleads___v3___services___bidding_strategy_service_pb2___BiddingStrategyOperation,
    MutateBiddingStrategyResult as google___ads___googleads___v3___services___bidding_strategy_service_pb2___MutateBiddingStrategyResult,
)
from google.ads.google_ads.v3.proto.services.campaign_bid_modifier_service_pb2 import (
    CampaignBidModifierOperation as google___ads___googleads___v3___services___campaign_bid_modifier_service_pb2___CampaignBidModifierOperation,
    MutateCampaignBidModifierResult as google___ads___googleads___v3___services___campaign_bid_modifier_service_pb2___MutateCampaignBidModifierResult,
)
from google.ads.google_ads.v3.proto.services.campaign_budget_service_pb2 import (
    CampaignBudgetOperation as google___ads___googleads___v3___services___campaign_budget_service_pb2___CampaignBudgetOperation,
    MutateCampaignBudgetResult as google___ads___googleads___v3___services___campaign_budget_service_pb2___MutateCampaignBudgetResult,
)
from google.ads.google_ads.v3.proto.services.campaign_criterion_service_pb2 import (
    CampaignCriterionOperation as google___ads___googleads___v3___services___campaign_criterion_service_pb2___CampaignCriterionOperation,
    MutateCampaignCriterionResult as google___ads___googleads___v3___services___campaign_criterion_service_pb2___MutateCampaignCriterionResult,
)
from google.ads.google_ads.v3.proto.services.campaign_draft_service_pb2 import (
    CampaignDraftOperation as google___ads___googleads___v3___services___campaign_draft_service_pb2___CampaignDraftOperation,
    MutateCampaignDraftResult as google___ads___googleads___v3___services___campaign_draft_service_pb2___MutateCampaignDraftResult,
)
from google.ads.google_ads.v3.proto.services.campaign_experiment_service_pb2 import (
    CampaignExperimentOperation as google___ads___googleads___v3___services___campaign_experiment_service_pb2___CampaignExperimentOperation,
    MutateCampaignExperimentResult as google___ads___googleads___v3___services___campaign_experiment_service_pb2___MutateCampaignExperimentResult,
)
from google.ads.google_ads.v3.proto.services.campaign_extension_setting_service_pb2 import (
    CampaignExtensionSettingOperation as google___ads___googleads___v3___services___campaign_extension_setting_service_pb2___CampaignExtensionSettingOperation,
    MutateCampaignExtensionSettingResult as google___ads___googleads___v3___services___campaign_extension_setting_service_pb2___MutateCampaignExtensionSettingResult,
)
from google.ads.google_ads.v3.proto.services.campaign_feed_service_pb2 import (
    CampaignFeedOperation as google___ads___googleads___v3___services___campaign_feed_service_pb2___CampaignFeedOperation,
    MutateCampaignFeedResult as google___ads___googleads___v3___services___campaign_feed_service_pb2___MutateCampaignFeedResult,
)
from google.ads.google_ads.v3.proto.services.campaign_label_service_pb2 import (
    CampaignLabelOperation as google___ads___googleads___v3___services___campaign_label_service_pb2___CampaignLabelOperation,
    MutateCampaignLabelResult as google___ads___googleads___v3___services___campaign_label_service_pb2___MutateCampaignLabelResult,
)
from google.ads.google_ads.v3.proto.services.campaign_service_pb2 import (
    CampaignOperation as google___ads___googleads___v3___services___campaign_service_pb2___CampaignOperation,
    MutateCampaignResult as google___ads___googleads___v3___services___campaign_service_pb2___MutateCampaignResult,
)
from google.ads.google_ads.v3.proto.services.campaign_shared_set_service_pb2 import (
    CampaignSharedSetOperation as google___ads___googleads___v3___services___campaign_shared_set_service_pb2___CampaignSharedSetOperation,
    MutateCampaignSharedSetResult as google___ads___googleads___v3___services___campaign_shared_set_service_pb2___MutateCampaignSharedSetResult,
)
from google.ads.google_ads.v3.proto.services.conversion_action_service_pb2 import (
    ConversionActionOperation as google___ads___googleads___v3___services___conversion_action_service_pb2___ConversionActionOperation,
    MutateConversionActionResult as google___ads___googleads___v3___services___conversion_action_service_pb2___MutateConversionActionResult,
)
from google.ads.google_ads.v3.proto.services.customer_extension_setting_service_pb2 import (
    CustomerExtensionSettingOperation as google___ads___googleads___v3___services___customer_extension_setting_service_pb2___CustomerExtensionSettingOperation,
    MutateCustomerExtensionSettingResult as google___ads___googleads___v3___services___customer_extension_setting_service_pb2___MutateCustomerExtensionSettingResult,
)
from google.ads.google_ads.v3.proto.services.customer_feed_service_pb2 import (
    CustomerFeedOperation as google___ads___googleads___v3___services___customer_feed_service_pb2___CustomerFeedOperation,
    MutateCustomerFeedResult as google___ads___googleads___v3___services___customer_feed_service_pb2___MutateCustomerFeedResult,
)
from google.ads.google_ads.v3.proto.services.customer_label_service_pb2 import (
    CustomerLabelOperation as google___ads___googleads___v3___services___customer_label_service_pb2___CustomerLabelOperation,
    MutateCustomerLabelResult as google___ads___googleads___v3___services___customer_label_service_pb2___MutateCustomerLabelResult,
)
from google.ads.google_ads.v3.proto.services.customer_negative_criterion_service_pb2 import (
    CustomerNegativeCriterionOperation as google___ads___googleads___v3___services___customer_negative_criterion_service_pb2___CustomerNegativeCriterionOperation,
    MutateCustomerNegativeCriteriaResult as google___ads___googleads___v3___services___customer_negative_criterion_service_pb2___MutateCustomerNegativeCriteriaResult,
)
from google.ads.google_ads.v3.proto.services.customer_service_pb2 import (
    CustomerOperation as google___ads___googleads___v3___services___customer_service_pb2___CustomerOperation,
    MutateCustomerResult as google___ads___googleads___v3___services___customer_service_pb2___MutateCustomerResult,
)
from google.ads.google_ads.v3.proto.services.extension_feed_item_service_pb2 import (
    ExtensionFeedItemOperation as google___ads___googleads___v3___services___extension_feed_item_service_pb2___ExtensionFeedItemOperation,
    MutateExtensionFeedItemResult as google___ads___googleads___v3___services___extension_feed_item_service_pb2___MutateExtensionFeedItemResult,
)
from google.ads.google_ads.v3.proto.services.feed_item_service_pb2 import (
    FeedItemOperation as google___ads___googleads___v3___services___feed_item_service_pb2___FeedItemOperation,
    MutateFeedItemResult as google___ads___googleads___v3___services___feed_item_service_pb2___MutateFeedItemResult,
)
from google.ads.google_ads.v3.proto.services.feed_item_target_service_pb2 import (
    FeedItemTargetOperation as google___ads___googleads___v3___services___feed_item_target_service_pb2___FeedItemTargetOperation,
    MutateFeedItemTargetResult as google___ads___googleads___v3___services___feed_item_target_service_pb2___MutateFeedItemTargetResult,
)
from google.ads.google_ads.v3.proto.services.feed_mapping_service_pb2 import (
    FeedMappingOperation as google___ads___googleads___v3___services___feed_mapping_service_pb2___FeedMappingOperation,
    MutateFeedMappingResult as google___ads___googleads___v3___services___feed_mapping_service_pb2___MutateFeedMappingResult,
)
from google.ads.google_ads.v3.proto.services.feed_service_pb2 import (
    FeedOperation as google___ads___googleads___v3___services___feed_service_pb2___FeedOperation,
    MutateFeedResult as google___ads___googleads___v3___services___feed_service_pb2___MutateFeedResult,
)
from google.ads.google_ads.v3.proto.services.label_service_pb2 import (
    LabelOperation as google___ads___googleads___v3___services___label_service_pb2___LabelOperation,
    MutateLabelResult as google___ads___googleads___v3___services___label_service_pb2___MutateLabelResult,
)
from google.ads.google_ads.v3.proto.services.media_file_service_pb2 import (
    MediaFileOperation as google___ads___googleads___v3___services___media_file_service_pb2___MediaFileOperation,
    MutateMediaFileResult as google___ads___googleads___v3___services___media_file_service_pb2___MutateMediaFileResult,
)
from google.ads.google_ads.v3.proto.services.remarketing_action_service_pb2 import (
    MutateRemarketingActionResult as google___ads___googleads___v3___services___remarketing_action_service_pb2___MutateRemarketingActionResult,
    RemarketingActionOperation as google___ads___googleads___v3___services___remarketing_action_service_pb2___RemarketingActionOperation,
)
from google.ads.google_ads.v3.proto.services.shared_criterion_service_pb2 import (
    MutateSharedCriterionResult as google___ads___googleads___v3___services___shared_criterion_service_pb2___MutateSharedCriterionResult,
    SharedCriterionOperation as google___ads___googleads___v3___services___shared_criterion_service_pb2___SharedCriterionOperation,
)
from google.ads.google_ads.v3.proto.services.shared_set_service_pb2 import (
    MutateSharedSetResult as google___ads___googleads___v3___services___shared_set_service_pb2___MutateSharedSetResult,
    SharedSetOperation as google___ads___googleads___v3___services___shared_set_service_pb2___SharedSetOperation,
)
from google.ads.google_ads.v3.proto.services.user_list_service_pb2 import (
    MutateUserListResult as google___ads___googleads___v3___services___user_list_service_pb2___MutateUserListResult,
    UserListOperation as google___ads___googleads___v3___services___user_list_service_pb2___UserListOperation,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SearchGoogleAdsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    query: typing___Text = ...
    page_token: typing___Text = ...
    page_size: builtin___int = ...
    validate_only: builtin___bool = ...
    return_total_results_count: builtin___bool = ...
    summary_row_setting: google___ads___googleads___v3___enums___summary_row_setting_pb2___SummaryRowSettingEnum.SummaryRowSettingValue = ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        query: typing___Optional[typing___Text] = None,
        page_token: typing___Optional[typing___Text] = None,
        page_size: typing___Optional[builtin___int] = None,
        validate_only: typing___Optional[builtin___bool] = None,
        return_total_results_count: typing___Optional[builtin___bool] = None,
        summary_row_setting: typing___Optional[
            google___ads___googleads___v3___enums___summary_row_setting_pb2___SummaryRowSettingEnum.SummaryRowSettingValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "page_size",
            b"page_size",
            "page_token",
            b"page_token",
            "query",
            b"query",
            "return_total_results_count",
            b"return_total_results_count",
            "summary_row_setting",
            b"summary_row_setting",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

type___SearchGoogleAdsRequest = SearchGoogleAdsRequest

class SearchGoogleAdsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    next_page_token: typing___Text = ...
    total_results_count: builtin___int = ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___GoogleAdsRow
    ]: ...
    @property
    def field_mask(self) -> google___protobuf___field_mask_pb2___FieldMask: ...
    @property
    def summary_row(self) -> type___GoogleAdsRow: ...
    def __init__(
        self,
        *,
        results: typing___Optional[typing___Iterable[type___GoogleAdsRow]] = None,
        next_page_token: typing___Optional[typing___Text] = None,
        total_results_count: typing___Optional[builtin___int] = None,
        field_mask: typing___Optional[
            google___protobuf___field_mask_pb2___FieldMask
        ] = None,
        summary_row: typing___Optional[type___GoogleAdsRow] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "field_mask", b"field_mask", "summary_row", b"summary_row"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "field_mask",
            b"field_mask",
            "next_page_token",
            b"next_page_token",
            "results",
            b"results",
            "summary_row",
            b"summary_row",
            "total_results_count",
            b"total_results_count",
        ],
    ) -> None: ...

type___SearchGoogleAdsResponse = SearchGoogleAdsResponse

class SearchGoogleAdsStreamRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    query: typing___Text = ...
    summary_row_setting: google___ads___googleads___v3___enums___summary_row_setting_pb2___SummaryRowSettingEnum.SummaryRowSettingValue = ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        query: typing___Optional[typing___Text] = None,
        summary_row_setting: typing___Optional[
            google___ads___googleads___v3___enums___summary_row_setting_pb2___SummaryRowSettingEnum.SummaryRowSettingValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "query",
            b"query",
            "summary_row_setting",
            b"summary_row_setting",
        ],
    ) -> None: ...

type___SearchGoogleAdsStreamRequest = SearchGoogleAdsStreamRequest

class SearchGoogleAdsStreamResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___GoogleAdsRow
    ]: ...
    @property
    def field_mask(self) -> google___protobuf___field_mask_pb2___FieldMask: ...
    @property
    def summary_row(self) -> type___GoogleAdsRow: ...
    def __init__(
        self,
        *,
        results: typing___Optional[typing___Iterable[type___GoogleAdsRow]] = None,
        field_mask: typing___Optional[
            google___protobuf___field_mask_pb2___FieldMask
        ] = None,
        summary_row: typing___Optional[type___GoogleAdsRow] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "field_mask", b"field_mask", "summary_row", b"summary_row"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "field_mask",
            b"field_mask",
            "results",
            b"results",
            "summary_row",
            b"summary_row",
        ],
    ) -> None: ...

type___SearchGoogleAdsStreamResponse = SearchGoogleAdsStreamResponse

class GoogleAdsRow(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def account_budget(
        self,
    ) -> google___ads___googleads___v3___resources___account_budget_pb2___AccountBudget: ...
    @property
    def account_budget_proposal(
        self,
    ) -> google___ads___googleads___v3___resources___account_budget_proposal_pb2___AccountBudgetProposal: ...
    @property
    def ad_group(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_pb2___AdGroup: ...
    @property
    def ad_group_ad(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_ad_pb2___AdGroupAd: ...
    @property
    def ad_group_ad_asset_view(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_ad_asset_view_pb2___AdGroupAdAssetView: ...
    @property
    def ad_group_ad_label(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_ad_label_pb2___AdGroupAdLabel: ...
    @property
    def ad_group_audience_view(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_audience_view_pb2___AdGroupAudienceView: ...
    @property
    def ad_group_bid_modifier(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_bid_modifier_pb2___AdGroupBidModifier: ...
    @property
    def ad_group_criterion(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_criterion_pb2___AdGroupCriterion: ...
    @property
    def ad_group_criterion_label(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_criterion_label_pb2___AdGroupCriterionLabel: ...
    @property
    def ad_group_criterion_simulation(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_criterion_simulation_pb2___AdGroupCriterionSimulation: ...
    @property
    def ad_group_extension_setting(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_extension_setting_pb2___AdGroupExtensionSetting: ...
    @property
    def ad_group_feed(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_feed_pb2___AdGroupFeed: ...
    @property
    def ad_group_label(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_label_pb2___AdGroupLabel: ...
    @property
    def ad_group_simulation(
        self,
    ) -> google___ads___googleads___v3___resources___ad_group_simulation_pb2___AdGroupSimulation: ...
    @property
    def ad_parameter(
        self,
    ) -> google___ads___googleads___v3___resources___ad_parameter_pb2___AdParameter: ...
    @property
    def age_range_view(
        self,
    ) -> google___ads___googleads___v3___resources___age_range_view_pb2___AgeRangeView: ...
    @property
    def ad_schedule_view(
        self,
    ) -> google___ads___googleads___v3___resources___ad_schedule_view_pb2___AdScheduleView: ...
    @property
    def domain_category(
        self,
    ) -> google___ads___googleads___v3___resources___domain_category_pb2___DomainCategory: ...
    @property
    def asset(
        self,
    ) -> google___ads___googleads___v3___resources___asset_pb2___Asset: ...
    @property
    def bidding_strategy(
        self,
    ) -> google___ads___googleads___v3___resources___bidding_strategy_pb2___BiddingStrategy: ...
    @property
    def billing_setup(
        self,
    ) -> google___ads___googleads___v3___resources___billing_setup_pb2___BillingSetup: ...
    @property
    def campaign_budget(
        self,
    ) -> google___ads___googleads___v3___resources___campaign_budget_pb2___CampaignBudget: ...
    @property
    def campaign(
        self,
    ) -> google___ads___googleads___v3___resources___campaign_pb2___Campaign: ...
    @property
    def campaign_audience_view(
        self,
    ) -> google___ads___googleads___v3___resources___campaign_audience_view_pb2___CampaignAudienceView: ...
    @property
    def campaign_bid_modifier(
        self,
    ) -> google___ads___googleads___v3___resources___campaign_bid_modifier_pb2___CampaignBidModifier: ...
    @property
    def campaign_criterion(
        self,
    ) -> google___ads___googleads___v3___resources___campaign_criterion_pb2___CampaignCriterion: ...
    @property
    def campaign_criterion_simulation(
        self,
    ) -> google___ads___googleads___v3___resources___campaign_criterion_simulation_pb2___CampaignCriterionSimulation: ...
    @property
    def campaign_draft(
        self,
    ) -> google___ads___googleads___v3___resources___campaign_draft_pb2___CampaignDraft: ...
    @property
    def campaign_experiment(
        self,
    ) -> google___ads___googleads___v3___resources___campaign_experiment_pb2___CampaignExperiment: ...
    @property
    def campaign_extension_setting(
        self,
    ) -> google___ads___googleads___v3___resources___campaign_extension_setting_pb2___CampaignExtensionSetting: ...
    @property
    def campaign_feed(
        self,
    ) -> google___ads___googleads___v3___resources___campaign_feed_pb2___CampaignFeed: ...
    @property
    def campaign_label(
        self,
    ) -> google___ads___googleads___v3___resources___campaign_label_pb2___CampaignLabel: ...
    @property
    def campaign_shared_set(
        self,
    ) -> google___ads___googleads___v3___resources___campaign_shared_set_pb2___CampaignSharedSet: ...
    @property
    def carrier_constant(
        self,
    ) -> google___ads___googleads___v3___resources___carrier_constant_pb2___CarrierConstant: ...
    @property
    def change_status(
        self,
    ) -> google___ads___googleads___v3___resources___change_status_pb2___ChangeStatus: ...
    @property
    def conversion_action(
        self,
    ) -> google___ads___googleads___v3___resources___conversion_action_pb2___ConversionAction: ...
    @property
    def click_view(
        self,
    ) -> google___ads___googleads___v3___resources___click_view_pb2___ClickView: ...
    @property
    def currency_constant(
        self,
    ) -> google___ads___googleads___v3___resources___currency_constant_pb2___CurrencyConstant: ...
    @property
    def custom_interest(
        self,
    ) -> google___ads___googleads___v3___resources___custom_interest_pb2___CustomInterest: ...
    @property
    def customer(
        self,
    ) -> google___ads___googleads___v3___resources___customer_pb2___Customer: ...
    @property
    def customer_manager_link(
        self,
    ) -> google___ads___googleads___v3___resources___customer_manager_link_pb2___CustomerManagerLink: ...
    @property
    def customer_client_link(
        self,
    ) -> google___ads___googleads___v3___resources___customer_client_link_pb2___CustomerClientLink: ...
    @property
    def customer_client(
        self,
    ) -> google___ads___googleads___v3___resources___customer_client_pb2___CustomerClient: ...
    @property
    def customer_extension_setting(
        self,
    ) -> google___ads___googleads___v3___resources___customer_extension_setting_pb2___CustomerExtensionSetting: ...
    @property
    def customer_feed(
        self,
    ) -> google___ads___googleads___v3___resources___customer_feed_pb2___CustomerFeed: ...
    @property
    def customer_label(
        self,
    ) -> google___ads___googleads___v3___resources___customer_label_pb2___CustomerLabel: ...
    @property
    def customer_negative_criterion(
        self,
    ) -> google___ads___googleads___v3___resources___customer_negative_criterion_pb2___CustomerNegativeCriterion: ...
    @property
    def detail_placement_view(
        self,
    ) -> google___ads___googleads___v3___resources___detail_placement_view_pb2___DetailPlacementView: ...
    @property
    def display_keyword_view(
        self,
    ) -> google___ads___googleads___v3___resources___display_keyword_view_pb2___DisplayKeywordView: ...
    @property
    def distance_view(
        self,
    ) -> google___ads___googleads___v3___resources___distance_view_pb2___DistanceView: ...
    @property
    def dynamic_search_ads_search_term_view(
        self,
    ) -> google___ads___googleads___v3___resources___dynamic_search_ads_search_term_view_pb2___DynamicSearchAdsSearchTermView: ...
    @property
    def expanded_landing_page_view(
        self,
    ) -> google___ads___googleads___v3___resources___expanded_landing_page_view_pb2___ExpandedLandingPageView: ...
    @property
    def extension_feed_item(
        self,
    ) -> google___ads___googleads___v3___resources___extension_feed_item_pb2___ExtensionFeedItem: ...
    @property
    def feed(self) -> google___ads___googleads___v3___resources___feed_pb2___Feed: ...
    @property
    def feed_item(
        self,
    ) -> google___ads___googleads___v3___resources___feed_item_pb2___FeedItem: ...
    @property
    def feed_item_target(
        self,
    ) -> google___ads___googleads___v3___resources___feed_item_target_pb2___FeedItemTarget: ...
    @property
    def feed_mapping(
        self,
    ) -> google___ads___googleads___v3___resources___feed_mapping_pb2___FeedMapping: ...
    @property
    def feed_placeholder_view(
        self,
    ) -> google___ads___googleads___v3___resources___feed_placeholder_view_pb2___FeedPlaceholderView: ...
    @property
    def gender_view(
        self,
    ) -> google___ads___googleads___v3___resources___gender_view_pb2___GenderView: ...
    @property
    def geo_target_constant(
        self,
    ) -> google___ads___googleads___v3___resources___geo_target_constant_pb2___GeoTargetConstant: ...
    @property
    def geographic_view(
        self,
    ) -> google___ads___googleads___v3___resources___geographic_view_pb2___GeographicView: ...
    @property
    def group_placement_view(
        self,
    ) -> google___ads___googleads___v3___resources___group_placement_view_pb2___GroupPlacementView: ...
    @property
    def hotel_group_view(
        self,
    ) -> google___ads___googleads___v3___resources___hotel_group_view_pb2___HotelGroupView: ...
    @property
    def hotel_performance_view(
        self,
    ) -> google___ads___googleads___v3___resources___hotel_performance_view_pb2___HotelPerformanceView: ...
    @property
    def keyword_view(
        self,
    ) -> google___ads___googleads___v3___resources___keyword_view_pb2___KeywordView: ...
    @property
    def keyword_plan(
        self,
    ) -> google___ads___googleads___v3___resources___keyword_plan_pb2___KeywordPlan: ...
    @property
    def keyword_plan_campaign(
        self,
    ) -> google___ads___googleads___v3___resources___keyword_plan_campaign_pb2___KeywordPlanCampaign: ...
    @property
    def keyword_plan_negative_keyword(
        self,
    ) -> google___ads___googleads___v3___resources___keyword_plan_negative_keyword_pb2___KeywordPlanNegativeKeyword: ...
    @property
    def keyword_plan_ad_group(
        self,
    ) -> google___ads___googleads___v3___resources___keyword_plan_ad_group_pb2___KeywordPlanAdGroup: ...
    @property
    def keyword_plan_keyword(
        self,
    ) -> google___ads___googleads___v3___resources___keyword_plan_keyword_pb2___KeywordPlanKeyword: ...
    @property
    def label(
        self,
    ) -> google___ads___googleads___v3___resources___label_pb2___Label: ...
    @property
    def landing_page_view(
        self,
    ) -> google___ads___googleads___v3___resources___landing_page_view_pb2___LandingPageView: ...
    @property
    def language_constant(
        self,
    ) -> google___ads___googleads___v3___resources___language_constant_pb2___LanguageConstant: ...
    @property
    def location_view(
        self,
    ) -> google___ads___googleads___v3___resources___location_view_pb2___LocationView: ...
    @property
    def managed_placement_view(
        self,
    ) -> google___ads___googleads___v3___resources___managed_placement_view_pb2___ManagedPlacementView: ...
    @property
    def media_file(
        self,
    ) -> google___ads___googleads___v3___resources___media_file_pb2___MediaFile: ...
    @property
    def mobile_app_category_constant(
        self,
    ) -> google___ads___googleads___v3___resources___mobile_app_category_constant_pb2___MobileAppCategoryConstant: ...
    @property
    def mobile_device_constant(
        self,
    ) -> google___ads___googleads___v3___resources___mobile_device_constant_pb2___MobileDeviceConstant: ...
    @property
    def mutate_job(
        self,
    ) -> google___ads___googleads___v3___resources___mutate_job_pb2___MutateJob: ...
    @property
    def offline_user_data_job(
        self,
    ) -> google___ads___googleads___v3___resources___offline_user_data_job_pb2___OfflineUserDataJob: ...
    @property
    def operating_system_version_constant(
        self,
    ) -> google___ads___googleads___v3___resources___operating_system_version_constant_pb2___OperatingSystemVersionConstant: ...
    @property
    def paid_organic_search_term_view(
        self,
    ) -> google___ads___googleads___v3___resources___paid_organic_search_term_view_pb2___PaidOrganicSearchTermView: ...
    @property
    def parental_status_view(
        self,
    ) -> google___ads___googleads___v3___resources___parental_status_view_pb2___ParentalStatusView: ...
    @property
    def product_bidding_category_constant(
        self,
    ) -> google___ads___googleads___v3___resources___product_bidding_category_constant_pb2___ProductBiddingCategoryConstant: ...
    @property
    def product_group_view(
        self,
    ) -> google___ads___googleads___v3___resources___product_group_view_pb2___ProductGroupView: ...
    @property
    def recommendation(
        self,
    ) -> google___ads___googleads___v3___resources___recommendation_pb2___Recommendation: ...
    @property
    def search_term_view(
        self,
    ) -> google___ads___googleads___v3___resources___search_term_view_pb2___SearchTermView: ...
    @property
    def shared_criterion(
        self,
    ) -> google___ads___googleads___v3___resources___shared_criterion_pb2___SharedCriterion: ...
    @property
    def shared_set(
        self,
    ) -> google___ads___googleads___v3___resources___shared_set_pb2___SharedSet: ...
    @property
    def shopping_performance_view(
        self,
    ) -> google___ads___googleads___v3___resources___shopping_performance_view_pb2___ShoppingPerformanceView: ...
    @property
    def topic_view(
        self,
    ) -> google___ads___googleads___v3___resources___topic_view_pb2___TopicView: ...
    @property
    def user_interest(
        self,
    ) -> google___ads___googleads___v3___resources___user_interest_pb2___UserInterest: ...
    @property
    def user_list(
        self,
    ) -> google___ads___googleads___v3___resources___user_list_pb2___UserList: ...
    @property
    def user_location_view(
        self,
    ) -> google___ads___googleads___v3___resources___user_location_view_pb2___UserLocationView: ...
    @property
    def remarketing_action(
        self,
    ) -> google___ads___googleads___v3___resources___remarketing_action_pb2___RemarketingAction: ...
    @property
    def topic_constant(
        self,
    ) -> google___ads___googleads___v3___resources___topic_constant_pb2___TopicConstant: ...
    @property
    def video(
        self,
    ) -> google___ads___googleads___v3___resources___video_pb2___Video: ...
    @property
    def metrics(
        self,
    ) -> google___ads___googleads___v3___common___metrics_pb2___Metrics: ...
    @property
    def segments(
        self,
    ) -> google___ads___googleads___v3___common___segments_pb2___Segments: ...
    def __init__(
        self,
        *,
        account_budget: typing___Optional[
            google___ads___googleads___v3___resources___account_budget_pb2___AccountBudget
        ] = None,
        account_budget_proposal: typing___Optional[
            google___ads___googleads___v3___resources___account_budget_proposal_pb2___AccountBudgetProposal
        ] = None,
        ad_group: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_pb2___AdGroup
        ] = None,
        ad_group_ad: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_ad_pb2___AdGroupAd
        ] = None,
        ad_group_ad_asset_view: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_ad_asset_view_pb2___AdGroupAdAssetView
        ] = None,
        ad_group_ad_label: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_ad_label_pb2___AdGroupAdLabel
        ] = None,
        ad_group_audience_view: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_audience_view_pb2___AdGroupAudienceView
        ] = None,
        ad_group_bid_modifier: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_bid_modifier_pb2___AdGroupBidModifier
        ] = None,
        ad_group_criterion: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_criterion_pb2___AdGroupCriterion
        ] = None,
        ad_group_criterion_label: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_criterion_label_pb2___AdGroupCriterionLabel
        ] = None,
        ad_group_criterion_simulation: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_criterion_simulation_pb2___AdGroupCriterionSimulation
        ] = None,
        ad_group_extension_setting: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_extension_setting_pb2___AdGroupExtensionSetting
        ] = None,
        ad_group_feed: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_feed_pb2___AdGroupFeed
        ] = None,
        ad_group_label: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_label_pb2___AdGroupLabel
        ] = None,
        ad_group_simulation: typing___Optional[
            google___ads___googleads___v3___resources___ad_group_simulation_pb2___AdGroupSimulation
        ] = None,
        ad_parameter: typing___Optional[
            google___ads___googleads___v3___resources___ad_parameter_pb2___AdParameter
        ] = None,
        age_range_view: typing___Optional[
            google___ads___googleads___v3___resources___age_range_view_pb2___AgeRangeView
        ] = None,
        ad_schedule_view: typing___Optional[
            google___ads___googleads___v3___resources___ad_schedule_view_pb2___AdScheduleView
        ] = None,
        domain_category: typing___Optional[
            google___ads___googleads___v3___resources___domain_category_pb2___DomainCategory
        ] = None,
        asset: typing___Optional[
            google___ads___googleads___v3___resources___asset_pb2___Asset
        ] = None,
        bidding_strategy: typing___Optional[
            google___ads___googleads___v3___resources___bidding_strategy_pb2___BiddingStrategy
        ] = None,
        billing_setup: typing___Optional[
            google___ads___googleads___v3___resources___billing_setup_pb2___BillingSetup
        ] = None,
        campaign_budget: typing___Optional[
            google___ads___googleads___v3___resources___campaign_budget_pb2___CampaignBudget
        ] = None,
        campaign: typing___Optional[
            google___ads___googleads___v3___resources___campaign_pb2___Campaign
        ] = None,
        campaign_audience_view: typing___Optional[
            google___ads___googleads___v3___resources___campaign_audience_view_pb2___CampaignAudienceView
        ] = None,
        campaign_bid_modifier: typing___Optional[
            google___ads___googleads___v3___resources___campaign_bid_modifier_pb2___CampaignBidModifier
        ] = None,
        campaign_criterion: typing___Optional[
            google___ads___googleads___v3___resources___campaign_criterion_pb2___CampaignCriterion
        ] = None,
        campaign_criterion_simulation: typing___Optional[
            google___ads___googleads___v3___resources___campaign_criterion_simulation_pb2___CampaignCriterionSimulation
        ] = None,
        campaign_draft: typing___Optional[
            google___ads___googleads___v3___resources___campaign_draft_pb2___CampaignDraft
        ] = None,
        campaign_experiment: typing___Optional[
            google___ads___googleads___v3___resources___campaign_experiment_pb2___CampaignExperiment
        ] = None,
        campaign_extension_setting: typing___Optional[
            google___ads___googleads___v3___resources___campaign_extension_setting_pb2___CampaignExtensionSetting
        ] = None,
        campaign_feed: typing___Optional[
            google___ads___googleads___v3___resources___campaign_feed_pb2___CampaignFeed
        ] = None,
        campaign_label: typing___Optional[
            google___ads___googleads___v3___resources___campaign_label_pb2___CampaignLabel
        ] = None,
        campaign_shared_set: typing___Optional[
            google___ads___googleads___v3___resources___campaign_shared_set_pb2___CampaignSharedSet
        ] = None,
        carrier_constant: typing___Optional[
            google___ads___googleads___v3___resources___carrier_constant_pb2___CarrierConstant
        ] = None,
        change_status: typing___Optional[
            google___ads___googleads___v3___resources___change_status_pb2___ChangeStatus
        ] = None,
        conversion_action: typing___Optional[
            google___ads___googleads___v3___resources___conversion_action_pb2___ConversionAction
        ] = None,
        click_view: typing___Optional[
            google___ads___googleads___v3___resources___click_view_pb2___ClickView
        ] = None,
        currency_constant: typing___Optional[
            google___ads___googleads___v3___resources___currency_constant_pb2___CurrencyConstant
        ] = None,
        custom_interest: typing___Optional[
            google___ads___googleads___v3___resources___custom_interest_pb2___CustomInterest
        ] = None,
        customer: typing___Optional[
            google___ads___googleads___v3___resources___customer_pb2___Customer
        ] = None,
        customer_manager_link: typing___Optional[
            google___ads___googleads___v3___resources___customer_manager_link_pb2___CustomerManagerLink
        ] = None,
        customer_client_link: typing___Optional[
            google___ads___googleads___v3___resources___customer_client_link_pb2___CustomerClientLink
        ] = None,
        customer_client: typing___Optional[
            google___ads___googleads___v3___resources___customer_client_pb2___CustomerClient
        ] = None,
        customer_extension_setting: typing___Optional[
            google___ads___googleads___v3___resources___customer_extension_setting_pb2___CustomerExtensionSetting
        ] = None,
        customer_feed: typing___Optional[
            google___ads___googleads___v3___resources___customer_feed_pb2___CustomerFeed
        ] = None,
        customer_label: typing___Optional[
            google___ads___googleads___v3___resources___customer_label_pb2___CustomerLabel
        ] = None,
        customer_negative_criterion: typing___Optional[
            google___ads___googleads___v3___resources___customer_negative_criterion_pb2___CustomerNegativeCriterion
        ] = None,
        detail_placement_view: typing___Optional[
            google___ads___googleads___v3___resources___detail_placement_view_pb2___DetailPlacementView
        ] = None,
        display_keyword_view: typing___Optional[
            google___ads___googleads___v3___resources___display_keyword_view_pb2___DisplayKeywordView
        ] = None,
        distance_view: typing___Optional[
            google___ads___googleads___v3___resources___distance_view_pb2___DistanceView
        ] = None,
        dynamic_search_ads_search_term_view: typing___Optional[
            google___ads___googleads___v3___resources___dynamic_search_ads_search_term_view_pb2___DynamicSearchAdsSearchTermView
        ] = None,
        expanded_landing_page_view: typing___Optional[
            google___ads___googleads___v3___resources___expanded_landing_page_view_pb2___ExpandedLandingPageView
        ] = None,
        extension_feed_item: typing___Optional[
            google___ads___googleads___v3___resources___extension_feed_item_pb2___ExtensionFeedItem
        ] = None,
        feed: typing___Optional[
            google___ads___googleads___v3___resources___feed_pb2___Feed
        ] = None,
        feed_item: typing___Optional[
            google___ads___googleads___v3___resources___feed_item_pb2___FeedItem
        ] = None,
        feed_item_target: typing___Optional[
            google___ads___googleads___v3___resources___feed_item_target_pb2___FeedItemTarget
        ] = None,
        feed_mapping: typing___Optional[
            google___ads___googleads___v3___resources___feed_mapping_pb2___FeedMapping
        ] = None,
        feed_placeholder_view: typing___Optional[
            google___ads___googleads___v3___resources___feed_placeholder_view_pb2___FeedPlaceholderView
        ] = None,
        gender_view: typing___Optional[
            google___ads___googleads___v3___resources___gender_view_pb2___GenderView
        ] = None,
        geo_target_constant: typing___Optional[
            google___ads___googleads___v3___resources___geo_target_constant_pb2___GeoTargetConstant
        ] = None,
        geographic_view: typing___Optional[
            google___ads___googleads___v3___resources___geographic_view_pb2___GeographicView
        ] = None,
        group_placement_view: typing___Optional[
            google___ads___googleads___v3___resources___group_placement_view_pb2___GroupPlacementView
        ] = None,
        hotel_group_view: typing___Optional[
            google___ads___googleads___v3___resources___hotel_group_view_pb2___HotelGroupView
        ] = None,
        hotel_performance_view: typing___Optional[
            google___ads___googleads___v3___resources___hotel_performance_view_pb2___HotelPerformanceView
        ] = None,
        keyword_view: typing___Optional[
            google___ads___googleads___v3___resources___keyword_view_pb2___KeywordView
        ] = None,
        keyword_plan: typing___Optional[
            google___ads___googleads___v3___resources___keyword_plan_pb2___KeywordPlan
        ] = None,
        keyword_plan_campaign: typing___Optional[
            google___ads___googleads___v3___resources___keyword_plan_campaign_pb2___KeywordPlanCampaign
        ] = None,
        keyword_plan_negative_keyword: typing___Optional[
            google___ads___googleads___v3___resources___keyword_plan_negative_keyword_pb2___KeywordPlanNegativeKeyword
        ] = None,
        keyword_plan_ad_group: typing___Optional[
            google___ads___googleads___v3___resources___keyword_plan_ad_group_pb2___KeywordPlanAdGroup
        ] = None,
        keyword_plan_keyword: typing___Optional[
            google___ads___googleads___v3___resources___keyword_plan_keyword_pb2___KeywordPlanKeyword
        ] = None,
        label: typing___Optional[
            google___ads___googleads___v3___resources___label_pb2___Label
        ] = None,
        landing_page_view: typing___Optional[
            google___ads___googleads___v3___resources___landing_page_view_pb2___LandingPageView
        ] = None,
        language_constant: typing___Optional[
            google___ads___googleads___v3___resources___language_constant_pb2___LanguageConstant
        ] = None,
        location_view: typing___Optional[
            google___ads___googleads___v3___resources___location_view_pb2___LocationView
        ] = None,
        managed_placement_view: typing___Optional[
            google___ads___googleads___v3___resources___managed_placement_view_pb2___ManagedPlacementView
        ] = None,
        media_file: typing___Optional[
            google___ads___googleads___v3___resources___media_file_pb2___MediaFile
        ] = None,
        mobile_app_category_constant: typing___Optional[
            google___ads___googleads___v3___resources___mobile_app_category_constant_pb2___MobileAppCategoryConstant
        ] = None,
        mobile_device_constant: typing___Optional[
            google___ads___googleads___v3___resources___mobile_device_constant_pb2___MobileDeviceConstant
        ] = None,
        mutate_job: typing___Optional[
            google___ads___googleads___v3___resources___mutate_job_pb2___MutateJob
        ] = None,
        offline_user_data_job: typing___Optional[
            google___ads___googleads___v3___resources___offline_user_data_job_pb2___OfflineUserDataJob
        ] = None,
        operating_system_version_constant: typing___Optional[
            google___ads___googleads___v3___resources___operating_system_version_constant_pb2___OperatingSystemVersionConstant
        ] = None,
        paid_organic_search_term_view: typing___Optional[
            google___ads___googleads___v3___resources___paid_organic_search_term_view_pb2___PaidOrganicSearchTermView
        ] = None,
        parental_status_view: typing___Optional[
            google___ads___googleads___v3___resources___parental_status_view_pb2___ParentalStatusView
        ] = None,
        product_bidding_category_constant: typing___Optional[
            google___ads___googleads___v3___resources___product_bidding_category_constant_pb2___ProductBiddingCategoryConstant
        ] = None,
        product_group_view: typing___Optional[
            google___ads___googleads___v3___resources___product_group_view_pb2___ProductGroupView
        ] = None,
        recommendation: typing___Optional[
            google___ads___googleads___v3___resources___recommendation_pb2___Recommendation
        ] = None,
        search_term_view: typing___Optional[
            google___ads___googleads___v3___resources___search_term_view_pb2___SearchTermView
        ] = None,
        shared_criterion: typing___Optional[
            google___ads___googleads___v3___resources___shared_criterion_pb2___SharedCriterion
        ] = None,
        shared_set: typing___Optional[
            google___ads___googleads___v3___resources___shared_set_pb2___SharedSet
        ] = None,
        shopping_performance_view: typing___Optional[
            google___ads___googleads___v3___resources___shopping_performance_view_pb2___ShoppingPerformanceView
        ] = None,
        topic_view: typing___Optional[
            google___ads___googleads___v3___resources___topic_view_pb2___TopicView
        ] = None,
        user_interest: typing___Optional[
            google___ads___googleads___v3___resources___user_interest_pb2___UserInterest
        ] = None,
        user_list: typing___Optional[
            google___ads___googleads___v3___resources___user_list_pb2___UserList
        ] = None,
        user_location_view: typing___Optional[
            google___ads___googleads___v3___resources___user_location_view_pb2___UserLocationView
        ] = None,
        remarketing_action: typing___Optional[
            google___ads___googleads___v3___resources___remarketing_action_pb2___RemarketingAction
        ] = None,
        topic_constant: typing___Optional[
            google___ads___googleads___v3___resources___topic_constant_pb2___TopicConstant
        ] = None,
        video: typing___Optional[
            google___ads___googleads___v3___resources___video_pb2___Video
        ] = None,
        metrics: typing___Optional[
            google___ads___googleads___v3___common___metrics_pb2___Metrics
        ] = None,
        segments: typing___Optional[
            google___ads___googleads___v3___common___segments_pb2___Segments
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "account_budget",
            b"account_budget",
            "account_budget_proposal",
            b"account_budget_proposal",
            "ad_group",
            b"ad_group",
            "ad_group_ad",
            b"ad_group_ad",
            "ad_group_ad_asset_view",
            b"ad_group_ad_asset_view",
            "ad_group_ad_label",
            b"ad_group_ad_label",
            "ad_group_audience_view",
            b"ad_group_audience_view",
            "ad_group_bid_modifier",
            b"ad_group_bid_modifier",
            "ad_group_criterion",
            b"ad_group_criterion",
            "ad_group_criterion_label",
            b"ad_group_criterion_label",
            "ad_group_criterion_simulation",
            b"ad_group_criterion_simulation",
            "ad_group_extension_setting",
            b"ad_group_extension_setting",
            "ad_group_feed",
            b"ad_group_feed",
            "ad_group_label",
            b"ad_group_label",
            "ad_group_simulation",
            b"ad_group_simulation",
            "ad_parameter",
            b"ad_parameter",
            "ad_schedule_view",
            b"ad_schedule_view",
            "age_range_view",
            b"age_range_view",
            "asset",
            b"asset",
            "bidding_strategy",
            b"bidding_strategy",
            "billing_setup",
            b"billing_setup",
            "campaign",
            b"campaign",
            "campaign_audience_view",
            b"campaign_audience_view",
            "campaign_bid_modifier",
            b"campaign_bid_modifier",
            "campaign_budget",
            b"campaign_budget",
            "campaign_criterion",
            b"campaign_criterion",
            "campaign_criterion_simulation",
            b"campaign_criterion_simulation",
            "campaign_draft",
            b"campaign_draft",
            "campaign_experiment",
            b"campaign_experiment",
            "campaign_extension_setting",
            b"campaign_extension_setting",
            "campaign_feed",
            b"campaign_feed",
            "campaign_label",
            b"campaign_label",
            "campaign_shared_set",
            b"campaign_shared_set",
            "carrier_constant",
            b"carrier_constant",
            "change_status",
            b"change_status",
            "click_view",
            b"click_view",
            "conversion_action",
            b"conversion_action",
            "currency_constant",
            b"currency_constant",
            "custom_interest",
            b"custom_interest",
            "customer",
            b"customer",
            "customer_client",
            b"customer_client",
            "customer_client_link",
            b"customer_client_link",
            "customer_extension_setting",
            b"customer_extension_setting",
            "customer_feed",
            b"customer_feed",
            "customer_label",
            b"customer_label",
            "customer_manager_link",
            b"customer_manager_link",
            "customer_negative_criterion",
            b"customer_negative_criterion",
            "detail_placement_view",
            b"detail_placement_view",
            "display_keyword_view",
            b"display_keyword_view",
            "distance_view",
            b"distance_view",
            "domain_category",
            b"domain_category",
            "dynamic_search_ads_search_term_view",
            b"dynamic_search_ads_search_term_view",
            "expanded_landing_page_view",
            b"expanded_landing_page_view",
            "extension_feed_item",
            b"extension_feed_item",
            "feed",
            b"feed",
            "feed_item",
            b"feed_item",
            "feed_item_target",
            b"feed_item_target",
            "feed_mapping",
            b"feed_mapping",
            "feed_placeholder_view",
            b"feed_placeholder_view",
            "gender_view",
            b"gender_view",
            "geo_target_constant",
            b"geo_target_constant",
            "geographic_view",
            b"geographic_view",
            "group_placement_view",
            b"group_placement_view",
            "hotel_group_view",
            b"hotel_group_view",
            "hotel_performance_view",
            b"hotel_performance_view",
            "keyword_plan",
            b"keyword_plan",
            "keyword_plan_ad_group",
            b"keyword_plan_ad_group",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "keyword_plan_keyword",
            b"keyword_plan_keyword",
            "keyword_plan_negative_keyword",
            b"keyword_plan_negative_keyword",
            "keyword_view",
            b"keyword_view",
            "label",
            b"label",
            "landing_page_view",
            b"landing_page_view",
            "language_constant",
            b"language_constant",
            "location_view",
            b"location_view",
            "managed_placement_view",
            b"managed_placement_view",
            "media_file",
            b"media_file",
            "metrics",
            b"metrics",
            "mobile_app_category_constant",
            b"mobile_app_category_constant",
            "mobile_device_constant",
            b"mobile_device_constant",
            "mutate_job",
            b"mutate_job",
            "offline_user_data_job",
            b"offline_user_data_job",
            "operating_system_version_constant",
            b"operating_system_version_constant",
            "paid_organic_search_term_view",
            b"paid_organic_search_term_view",
            "parental_status_view",
            b"parental_status_view",
            "product_bidding_category_constant",
            b"product_bidding_category_constant",
            "product_group_view",
            b"product_group_view",
            "recommendation",
            b"recommendation",
            "remarketing_action",
            b"remarketing_action",
            "search_term_view",
            b"search_term_view",
            "segments",
            b"segments",
            "shared_criterion",
            b"shared_criterion",
            "shared_set",
            b"shared_set",
            "shopping_performance_view",
            b"shopping_performance_view",
            "topic_constant",
            b"topic_constant",
            "topic_view",
            b"topic_view",
            "user_interest",
            b"user_interest",
            "user_list",
            b"user_list",
            "user_location_view",
            b"user_location_view",
            "video",
            b"video",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "account_budget",
            b"account_budget",
            "account_budget_proposal",
            b"account_budget_proposal",
            "ad_group",
            b"ad_group",
            "ad_group_ad",
            b"ad_group_ad",
            "ad_group_ad_asset_view",
            b"ad_group_ad_asset_view",
            "ad_group_ad_label",
            b"ad_group_ad_label",
            "ad_group_audience_view",
            b"ad_group_audience_view",
            "ad_group_bid_modifier",
            b"ad_group_bid_modifier",
            "ad_group_criterion",
            b"ad_group_criterion",
            "ad_group_criterion_label",
            b"ad_group_criterion_label",
            "ad_group_criterion_simulation",
            b"ad_group_criterion_simulation",
            "ad_group_extension_setting",
            b"ad_group_extension_setting",
            "ad_group_feed",
            b"ad_group_feed",
            "ad_group_label",
            b"ad_group_label",
            "ad_group_simulation",
            b"ad_group_simulation",
            "ad_parameter",
            b"ad_parameter",
            "ad_schedule_view",
            b"ad_schedule_view",
            "age_range_view",
            b"age_range_view",
            "asset",
            b"asset",
            "bidding_strategy",
            b"bidding_strategy",
            "billing_setup",
            b"billing_setup",
            "campaign",
            b"campaign",
            "campaign_audience_view",
            b"campaign_audience_view",
            "campaign_bid_modifier",
            b"campaign_bid_modifier",
            "campaign_budget",
            b"campaign_budget",
            "campaign_criterion",
            b"campaign_criterion",
            "campaign_criterion_simulation",
            b"campaign_criterion_simulation",
            "campaign_draft",
            b"campaign_draft",
            "campaign_experiment",
            b"campaign_experiment",
            "campaign_extension_setting",
            b"campaign_extension_setting",
            "campaign_feed",
            b"campaign_feed",
            "campaign_label",
            b"campaign_label",
            "campaign_shared_set",
            b"campaign_shared_set",
            "carrier_constant",
            b"carrier_constant",
            "change_status",
            b"change_status",
            "click_view",
            b"click_view",
            "conversion_action",
            b"conversion_action",
            "currency_constant",
            b"currency_constant",
            "custom_interest",
            b"custom_interest",
            "customer",
            b"customer",
            "customer_client",
            b"customer_client",
            "customer_client_link",
            b"customer_client_link",
            "customer_extension_setting",
            b"customer_extension_setting",
            "customer_feed",
            b"customer_feed",
            "customer_label",
            b"customer_label",
            "customer_manager_link",
            b"customer_manager_link",
            "customer_negative_criterion",
            b"customer_negative_criterion",
            "detail_placement_view",
            b"detail_placement_view",
            "display_keyword_view",
            b"display_keyword_view",
            "distance_view",
            b"distance_view",
            "domain_category",
            b"domain_category",
            "dynamic_search_ads_search_term_view",
            b"dynamic_search_ads_search_term_view",
            "expanded_landing_page_view",
            b"expanded_landing_page_view",
            "extension_feed_item",
            b"extension_feed_item",
            "feed",
            b"feed",
            "feed_item",
            b"feed_item",
            "feed_item_target",
            b"feed_item_target",
            "feed_mapping",
            b"feed_mapping",
            "feed_placeholder_view",
            b"feed_placeholder_view",
            "gender_view",
            b"gender_view",
            "geo_target_constant",
            b"geo_target_constant",
            "geographic_view",
            b"geographic_view",
            "group_placement_view",
            b"group_placement_view",
            "hotel_group_view",
            b"hotel_group_view",
            "hotel_performance_view",
            b"hotel_performance_view",
            "keyword_plan",
            b"keyword_plan",
            "keyword_plan_ad_group",
            b"keyword_plan_ad_group",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "keyword_plan_keyword",
            b"keyword_plan_keyword",
            "keyword_plan_negative_keyword",
            b"keyword_plan_negative_keyword",
            "keyword_view",
            b"keyword_view",
            "label",
            b"label",
            "landing_page_view",
            b"landing_page_view",
            "language_constant",
            b"language_constant",
            "location_view",
            b"location_view",
            "managed_placement_view",
            b"managed_placement_view",
            "media_file",
            b"media_file",
            "metrics",
            b"metrics",
            "mobile_app_category_constant",
            b"mobile_app_category_constant",
            "mobile_device_constant",
            b"mobile_device_constant",
            "mutate_job",
            b"mutate_job",
            "offline_user_data_job",
            b"offline_user_data_job",
            "operating_system_version_constant",
            b"operating_system_version_constant",
            "paid_organic_search_term_view",
            b"paid_organic_search_term_view",
            "parental_status_view",
            b"parental_status_view",
            "product_bidding_category_constant",
            b"product_bidding_category_constant",
            "product_group_view",
            b"product_group_view",
            "recommendation",
            b"recommendation",
            "remarketing_action",
            b"remarketing_action",
            "search_term_view",
            b"search_term_view",
            "segments",
            b"segments",
            "shared_criterion",
            b"shared_criterion",
            "shared_set",
            b"shared_set",
            "shopping_performance_view",
            b"shopping_performance_view",
            "topic_constant",
            b"topic_constant",
            "topic_view",
            b"topic_view",
            "user_interest",
            b"user_interest",
            "user_list",
            b"user_list",
            "user_location_view",
            b"user_location_view",
            "video",
            b"video",
        ],
    ) -> None: ...

type___GoogleAdsRow = GoogleAdsRow

class MutateGoogleAdsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    partial_failure: builtin___bool = ...
    validate_only: builtin___bool = ...
    @property
    def mutate_operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___MutateOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        mutate_operations: typing___Optional[
            typing___Iterable[type___MutateOperation]
        ] = None,
        partial_failure: typing___Optional[builtin___bool] = None,
        validate_only: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "mutate_operations",
            b"mutate_operations",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

type___MutateGoogleAdsRequest = MutateGoogleAdsRequest

class MutateGoogleAdsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...
    @property
    def mutate_operation_responses(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___MutateOperationResponse
    ]: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing___Optional[
            google___rpc___status_pb2___Status
        ] = None,
        mutate_operation_responses: typing___Optional[
            typing___Iterable[type___MutateOperationResponse]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "mutate_operation_responses",
            b"mutate_operation_responses",
            "partial_failure_error",
            b"partial_failure_error",
        ],
    ) -> None: ...

type___MutateGoogleAdsResponse = MutateGoogleAdsResponse

class MutateOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def ad_group_ad_label_operation(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_ad_label_service_pb2___AdGroupAdLabelOperation: ...
    @property
    def ad_group_ad_operation(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_ad_service_pb2___AdGroupAdOperation: ...
    @property
    def ad_group_bid_modifier_operation(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_bid_modifier_service_pb2___AdGroupBidModifierOperation: ...
    @property
    def ad_group_criterion_label_operation(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_criterion_label_service_pb2___AdGroupCriterionLabelOperation: ...
    @property
    def ad_group_criterion_operation(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_criterion_service_pb2___AdGroupCriterionOperation: ...
    @property
    def ad_group_extension_setting_operation(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_extension_setting_service_pb2___AdGroupExtensionSettingOperation: ...
    @property
    def ad_group_feed_operation(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_feed_service_pb2___AdGroupFeedOperation: ...
    @property
    def ad_group_label_operation(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_label_service_pb2___AdGroupLabelOperation: ...
    @property
    def ad_group_operation(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_service_pb2___AdGroupOperation: ...
    @property
    def ad_operation(
        self,
    ) -> google___ads___googleads___v3___services___ad_service_pb2___AdOperation: ...
    @property
    def ad_parameter_operation(
        self,
    ) -> google___ads___googleads___v3___services___ad_parameter_service_pb2___AdParameterOperation: ...
    @property
    def asset_operation(
        self,
    ) -> google___ads___googleads___v3___services___asset_service_pb2___AssetOperation: ...
    @property
    def bidding_strategy_operation(
        self,
    ) -> google___ads___googleads___v3___services___bidding_strategy_service_pb2___BiddingStrategyOperation: ...
    @property
    def campaign_bid_modifier_operation(
        self,
    ) -> google___ads___googleads___v3___services___campaign_bid_modifier_service_pb2___CampaignBidModifierOperation: ...
    @property
    def campaign_budget_operation(
        self,
    ) -> google___ads___googleads___v3___services___campaign_budget_service_pb2___CampaignBudgetOperation: ...
    @property
    def campaign_criterion_operation(
        self,
    ) -> google___ads___googleads___v3___services___campaign_criterion_service_pb2___CampaignCriterionOperation: ...
    @property
    def campaign_draft_operation(
        self,
    ) -> google___ads___googleads___v3___services___campaign_draft_service_pb2___CampaignDraftOperation: ...
    @property
    def campaign_experiment_operation(
        self,
    ) -> google___ads___googleads___v3___services___campaign_experiment_service_pb2___CampaignExperimentOperation: ...
    @property
    def campaign_extension_setting_operation(
        self,
    ) -> google___ads___googleads___v3___services___campaign_extension_setting_service_pb2___CampaignExtensionSettingOperation: ...
    @property
    def campaign_feed_operation(
        self,
    ) -> google___ads___googleads___v3___services___campaign_feed_service_pb2___CampaignFeedOperation: ...
    @property
    def campaign_label_operation(
        self,
    ) -> google___ads___googleads___v3___services___campaign_label_service_pb2___CampaignLabelOperation: ...
    @property
    def campaign_operation(
        self,
    ) -> google___ads___googleads___v3___services___campaign_service_pb2___CampaignOperation: ...
    @property
    def campaign_shared_set_operation(
        self,
    ) -> google___ads___googleads___v3___services___campaign_shared_set_service_pb2___CampaignSharedSetOperation: ...
    @property
    def conversion_action_operation(
        self,
    ) -> google___ads___googleads___v3___services___conversion_action_service_pb2___ConversionActionOperation: ...
    @property
    def customer_extension_setting_operation(
        self,
    ) -> google___ads___googleads___v3___services___customer_extension_setting_service_pb2___CustomerExtensionSettingOperation: ...
    @property
    def customer_feed_operation(
        self,
    ) -> google___ads___googleads___v3___services___customer_feed_service_pb2___CustomerFeedOperation: ...
    @property
    def customer_label_operation(
        self,
    ) -> google___ads___googleads___v3___services___customer_label_service_pb2___CustomerLabelOperation: ...
    @property
    def customer_negative_criterion_operation(
        self,
    ) -> google___ads___googleads___v3___services___customer_negative_criterion_service_pb2___CustomerNegativeCriterionOperation: ...
    @property
    def customer_operation(
        self,
    ) -> google___ads___googleads___v3___services___customer_service_pb2___CustomerOperation: ...
    @property
    def extension_feed_item_operation(
        self,
    ) -> google___ads___googleads___v3___services___extension_feed_item_service_pb2___ExtensionFeedItemOperation: ...
    @property
    def feed_item_operation(
        self,
    ) -> google___ads___googleads___v3___services___feed_item_service_pb2___FeedItemOperation: ...
    @property
    def feed_item_target_operation(
        self,
    ) -> google___ads___googleads___v3___services___feed_item_target_service_pb2___FeedItemTargetOperation: ...
    @property
    def feed_mapping_operation(
        self,
    ) -> google___ads___googleads___v3___services___feed_mapping_service_pb2___FeedMappingOperation: ...
    @property
    def feed_operation(
        self,
    ) -> google___ads___googleads___v3___services___feed_service_pb2___FeedOperation: ...
    @property
    def label_operation(
        self,
    ) -> google___ads___googleads___v3___services___label_service_pb2___LabelOperation: ...
    @property
    def media_file_operation(
        self,
    ) -> google___ads___googleads___v3___services___media_file_service_pb2___MediaFileOperation: ...
    @property
    def remarketing_action_operation(
        self,
    ) -> google___ads___googleads___v3___services___remarketing_action_service_pb2___RemarketingActionOperation: ...
    @property
    def shared_criterion_operation(
        self,
    ) -> google___ads___googleads___v3___services___shared_criterion_service_pb2___SharedCriterionOperation: ...
    @property
    def shared_set_operation(
        self,
    ) -> google___ads___googleads___v3___services___shared_set_service_pb2___SharedSetOperation: ...
    @property
    def user_list_operation(
        self,
    ) -> google___ads___googleads___v3___services___user_list_service_pb2___UserListOperation: ...
    def __init__(
        self,
        *,
        ad_group_ad_label_operation: typing___Optional[
            google___ads___googleads___v3___services___ad_group_ad_label_service_pb2___AdGroupAdLabelOperation
        ] = None,
        ad_group_ad_operation: typing___Optional[
            google___ads___googleads___v3___services___ad_group_ad_service_pb2___AdGroupAdOperation
        ] = None,
        ad_group_bid_modifier_operation: typing___Optional[
            google___ads___googleads___v3___services___ad_group_bid_modifier_service_pb2___AdGroupBidModifierOperation
        ] = None,
        ad_group_criterion_label_operation: typing___Optional[
            google___ads___googleads___v3___services___ad_group_criterion_label_service_pb2___AdGroupCriterionLabelOperation
        ] = None,
        ad_group_criterion_operation: typing___Optional[
            google___ads___googleads___v3___services___ad_group_criterion_service_pb2___AdGroupCriterionOperation
        ] = None,
        ad_group_extension_setting_operation: typing___Optional[
            google___ads___googleads___v3___services___ad_group_extension_setting_service_pb2___AdGroupExtensionSettingOperation
        ] = None,
        ad_group_feed_operation: typing___Optional[
            google___ads___googleads___v3___services___ad_group_feed_service_pb2___AdGroupFeedOperation
        ] = None,
        ad_group_label_operation: typing___Optional[
            google___ads___googleads___v3___services___ad_group_label_service_pb2___AdGroupLabelOperation
        ] = None,
        ad_group_operation: typing___Optional[
            google___ads___googleads___v3___services___ad_group_service_pb2___AdGroupOperation
        ] = None,
        ad_operation: typing___Optional[
            google___ads___googleads___v3___services___ad_service_pb2___AdOperation
        ] = None,
        ad_parameter_operation: typing___Optional[
            google___ads___googleads___v3___services___ad_parameter_service_pb2___AdParameterOperation
        ] = None,
        asset_operation: typing___Optional[
            google___ads___googleads___v3___services___asset_service_pb2___AssetOperation
        ] = None,
        bidding_strategy_operation: typing___Optional[
            google___ads___googleads___v3___services___bidding_strategy_service_pb2___BiddingStrategyOperation
        ] = None,
        campaign_bid_modifier_operation: typing___Optional[
            google___ads___googleads___v3___services___campaign_bid_modifier_service_pb2___CampaignBidModifierOperation
        ] = None,
        campaign_budget_operation: typing___Optional[
            google___ads___googleads___v3___services___campaign_budget_service_pb2___CampaignBudgetOperation
        ] = None,
        campaign_criterion_operation: typing___Optional[
            google___ads___googleads___v3___services___campaign_criterion_service_pb2___CampaignCriterionOperation
        ] = None,
        campaign_draft_operation: typing___Optional[
            google___ads___googleads___v3___services___campaign_draft_service_pb2___CampaignDraftOperation
        ] = None,
        campaign_experiment_operation: typing___Optional[
            google___ads___googleads___v3___services___campaign_experiment_service_pb2___CampaignExperimentOperation
        ] = None,
        campaign_extension_setting_operation: typing___Optional[
            google___ads___googleads___v3___services___campaign_extension_setting_service_pb2___CampaignExtensionSettingOperation
        ] = None,
        campaign_feed_operation: typing___Optional[
            google___ads___googleads___v3___services___campaign_feed_service_pb2___CampaignFeedOperation
        ] = None,
        campaign_label_operation: typing___Optional[
            google___ads___googleads___v3___services___campaign_label_service_pb2___CampaignLabelOperation
        ] = None,
        campaign_operation: typing___Optional[
            google___ads___googleads___v3___services___campaign_service_pb2___CampaignOperation
        ] = None,
        campaign_shared_set_operation: typing___Optional[
            google___ads___googleads___v3___services___campaign_shared_set_service_pb2___CampaignSharedSetOperation
        ] = None,
        conversion_action_operation: typing___Optional[
            google___ads___googleads___v3___services___conversion_action_service_pb2___ConversionActionOperation
        ] = None,
        customer_extension_setting_operation: typing___Optional[
            google___ads___googleads___v3___services___customer_extension_setting_service_pb2___CustomerExtensionSettingOperation
        ] = None,
        customer_feed_operation: typing___Optional[
            google___ads___googleads___v3___services___customer_feed_service_pb2___CustomerFeedOperation
        ] = None,
        customer_label_operation: typing___Optional[
            google___ads___googleads___v3___services___customer_label_service_pb2___CustomerLabelOperation
        ] = None,
        customer_negative_criterion_operation: typing___Optional[
            google___ads___googleads___v3___services___customer_negative_criterion_service_pb2___CustomerNegativeCriterionOperation
        ] = None,
        customer_operation: typing___Optional[
            google___ads___googleads___v3___services___customer_service_pb2___CustomerOperation
        ] = None,
        extension_feed_item_operation: typing___Optional[
            google___ads___googleads___v3___services___extension_feed_item_service_pb2___ExtensionFeedItemOperation
        ] = None,
        feed_item_operation: typing___Optional[
            google___ads___googleads___v3___services___feed_item_service_pb2___FeedItemOperation
        ] = None,
        feed_item_target_operation: typing___Optional[
            google___ads___googleads___v3___services___feed_item_target_service_pb2___FeedItemTargetOperation
        ] = None,
        feed_mapping_operation: typing___Optional[
            google___ads___googleads___v3___services___feed_mapping_service_pb2___FeedMappingOperation
        ] = None,
        feed_operation: typing___Optional[
            google___ads___googleads___v3___services___feed_service_pb2___FeedOperation
        ] = None,
        label_operation: typing___Optional[
            google___ads___googleads___v3___services___label_service_pb2___LabelOperation
        ] = None,
        media_file_operation: typing___Optional[
            google___ads___googleads___v3___services___media_file_service_pb2___MediaFileOperation
        ] = None,
        remarketing_action_operation: typing___Optional[
            google___ads___googleads___v3___services___remarketing_action_service_pb2___RemarketingActionOperation
        ] = None,
        shared_criterion_operation: typing___Optional[
            google___ads___googleads___v3___services___shared_criterion_service_pb2___SharedCriterionOperation
        ] = None,
        shared_set_operation: typing___Optional[
            google___ads___googleads___v3___services___shared_set_service_pb2___SharedSetOperation
        ] = None,
        user_list_operation: typing___Optional[
            google___ads___googleads___v3___services___user_list_service_pb2___UserListOperation
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group_ad_label_operation",
            b"ad_group_ad_label_operation",
            "ad_group_ad_operation",
            b"ad_group_ad_operation",
            "ad_group_bid_modifier_operation",
            b"ad_group_bid_modifier_operation",
            "ad_group_criterion_label_operation",
            b"ad_group_criterion_label_operation",
            "ad_group_criterion_operation",
            b"ad_group_criterion_operation",
            "ad_group_extension_setting_operation",
            b"ad_group_extension_setting_operation",
            "ad_group_feed_operation",
            b"ad_group_feed_operation",
            "ad_group_label_operation",
            b"ad_group_label_operation",
            "ad_group_operation",
            b"ad_group_operation",
            "ad_operation",
            b"ad_operation",
            "ad_parameter_operation",
            b"ad_parameter_operation",
            "asset_operation",
            b"asset_operation",
            "bidding_strategy_operation",
            b"bidding_strategy_operation",
            "campaign_bid_modifier_operation",
            b"campaign_bid_modifier_operation",
            "campaign_budget_operation",
            b"campaign_budget_operation",
            "campaign_criterion_operation",
            b"campaign_criterion_operation",
            "campaign_draft_operation",
            b"campaign_draft_operation",
            "campaign_experiment_operation",
            b"campaign_experiment_operation",
            "campaign_extension_setting_operation",
            b"campaign_extension_setting_operation",
            "campaign_feed_operation",
            b"campaign_feed_operation",
            "campaign_label_operation",
            b"campaign_label_operation",
            "campaign_operation",
            b"campaign_operation",
            "campaign_shared_set_operation",
            b"campaign_shared_set_operation",
            "conversion_action_operation",
            b"conversion_action_operation",
            "customer_extension_setting_operation",
            b"customer_extension_setting_operation",
            "customer_feed_operation",
            b"customer_feed_operation",
            "customer_label_operation",
            b"customer_label_operation",
            "customer_negative_criterion_operation",
            b"customer_negative_criterion_operation",
            "customer_operation",
            b"customer_operation",
            "extension_feed_item_operation",
            b"extension_feed_item_operation",
            "feed_item_operation",
            b"feed_item_operation",
            "feed_item_target_operation",
            b"feed_item_target_operation",
            "feed_mapping_operation",
            b"feed_mapping_operation",
            "feed_operation",
            b"feed_operation",
            "label_operation",
            b"label_operation",
            "media_file_operation",
            b"media_file_operation",
            "operation",
            b"operation",
            "remarketing_action_operation",
            b"remarketing_action_operation",
            "shared_criterion_operation",
            b"shared_criterion_operation",
            "shared_set_operation",
            b"shared_set_operation",
            "user_list_operation",
            b"user_list_operation",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group_ad_label_operation",
            b"ad_group_ad_label_operation",
            "ad_group_ad_operation",
            b"ad_group_ad_operation",
            "ad_group_bid_modifier_operation",
            b"ad_group_bid_modifier_operation",
            "ad_group_criterion_label_operation",
            b"ad_group_criterion_label_operation",
            "ad_group_criterion_operation",
            b"ad_group_criterion_operation",
            "ad_group_extension_setting_operation",
            b"ad_group_extension_setting_operation",
            "ad_group_feed_operation",
            b"ad_group_feed_operation",
            "ad_group_label_operation",
            b"ad_group_label_operation",
            "ad_group_operation",
            b"ad_group_operation",
            "ad_operation",
            b"ad_operation",
            "ad_parameter_operation",
            b"ad_parameter_operation",
            "asset_operation",
            b"asset_operation",
            "bidding_strategy_operation",
            b"bidding_strategy_operation",
            "campaign_bid_modifier_operation",
            b"campaign_bid_modifier_operation",
            "campaign_budget_operation",
            b"campaign_budget_operation",
            "campaign_criterion_operation",
            b"campaign_criterion_operation",
            "campaign_draft_operation",
            b"campaign_draft_operation",
            "campaign_experiment_operation",
            b"campaign_experiment_operation",
            "campaign_extension_setting_operation",
            b"campaign_extension_setting_operation",
            "campaign_feed_operation",
            b"campaign_feed_operation",
            "campaign_label_operation",
            b"campaign_label_operation",
            "campaign_operation",
            b"campaign_operation",
            "campaign_shared_set_operation",
            b"campaign_shared_set_operation",
            "conversion_action_operation",
            b"conversion_action_operation",
            "customer_extension_setting_operation",
            b"customer_extension_setting_operation",
            "customer_feed_operation",
            b"customer_feed_operation",
            "customer_label_operation",
            b"customer_label_operation",
            "customer_negative_criterion_operation",
            b"customer_negative_criterion_operation",
            "customer_operation",
            b"customer_operation",
            "extension_feed_item_operation",
            b"extension_feed_item_operation",
            "feed_item_operation",
            b"feed_item_operation",
            "feed_item_target_operation",
            b"feed_item_target_operation",
            "feed_mapping_operation",
            b"feed_mapping_operation",
            "feed_operation",
            b"feed_operation",
            "label_operation",
            b"label_operation",
            "media_file_operation",
            b"media_file_operation",
            "operation",
            b"operation",
            "remarketing_action_operation",
            b"remarketing_action_operation",
            "shared_criterion_operation",
            b"shared_criterion_operation",
            "shared_set_operation",
            b"shared_set_operation",
            "user_list_operation",
            b"user_list_operation",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["operation", b"operation"]
    ) -> typing_extensions___Literal[
        "ad_group_ad_label_operation",
        "ad_group_ad_operation",
        "ad_group_bid_modifier_operation",
        "ad_group_criterion_label_operation",
        "ad_group_criterion_operation",
        "ad_group_extension_setting_operation",
        "ad_group_feed_operation",
        "ad_group_label_operation",
        "ad_group_operation",
        "ad_operation",
        "ad_parameter_operation",
        "asset_operation",
        "bidding_strategy_operation",
        "campaign_bid_modifier_operation",
        "campaign_budget_operation",
        "campaign_criterion_operation",
        "campaign_draft_operation",
        "campaign_experiment_operation",
        "campaign_extension_setting_operation",
        "campaign_feed_operation",
        "campaign_label_operation",
        "campaign_operation",
        "campaign_shared_set_operation",
        "conversion_action_operation",
        "customer_extension_setting_operation",
        "customer_feed_operation",
        "customer_label_operation",
        "customer_negative_criterion_operation",
        "customer_operation",
        "extension_feed_item_operation",
        "feed_item_operation",
        "feed_item_target_operation",
        "feed_mapping_operation",
        "feed_operation",
        "label_operation",
        "media_file_operation",
        "remarketing_action_operation",
        "shared_criterion_operation",
        "shared_set_operation",
        "user_list_operation",
    ]: ...

type___MutateOperation = MutateOperation

class MutateOperationResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def ad_group_ad_label_result(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_ad_label_service_pb2___MutateAdGroupAdLabelResult: ...
    @property
    def ad_group_ad_result(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_ad_service_pb2___MutateAdGroupAdResult: ...
    @property
    def ad_group_bid_modifier_result(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_bid_modifier_service_pb2___MutateAdGroupBidModifierResult: ...
    @property
    def ad_group_criterion_label_result(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_criterion_label_service_pb2___MutateAdGroupCriterionLabelResult: ...
    @property
    def ad_group_criterion_result(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_criterion_service_pb2___MutateAdGroupCriterionResult: ...
    @property
    def ad_group_extension_setting_result(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_extension_setting_service_pb2___MutateAdGroupExtensionSettingResult: ...
    @property
    def ad_group_feed_result(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_feed_service_pb2___MutateAdGroupFeedResult: ...
    @property
    def ad_group_label_result(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_label_service_pb2___MutateAdGroupLabelResult: ...
    @property
    def ad_group_result(
        self,
    ) -> google___ads___googleads___v3___services___ad_group_service_pb2___MutateAdGroupResult: ...
    @property
    def ad_parameter_result(
        self,
    ) -> google___ads___googleads___v3___services___ad_parameter_service_pb2___MutateAdParameterResult: ...
    @property
    def ad_result(
        self,
    ) -> google___ads___googleads___v3___services___ad_service_pb2___MutateAdResult: ...
    @property
    def asset_result(
        self,
    ) -> google___ads___googleads___v3___services___asset_service_pb2___MutateAssetResult: ...
    @property
    def bidding_strategy_result(
        self,
    ) -> google___ads___googleads___v3___services___bidding_strategy_service_pb2___MutateBiddingStrategyResult: ...
    @property
    def campaign_bid_modifier_result(
        self,
    ) -> google___ads___googleads___v3___services___campaign_bid_modifier_service_pb2___MutateCampaignBidModifierResult: ...
    @property
    def campaign_budget_result(
        self,
    ) -> google___ads___googleads___v3___services___campaign_budget_service_pb2___MutateCampaignBudgetResult: ...
    @property
    def campaign_criterion_result(
        self,
    ) -> google___ads___googleads___v3___services___campaign_criterion_service_pb2___MutateCampaignCriterionResult: ...
    @property
    def campaign_draft_result(
        self,
    ) -> google___ads___googleads___v3___services___campaign_draft_service_pb2___MutateCampaignDraftResult: ...
    @property
    def campaign_experiment_result(
        self,
    ) -> google___ads___googleads___v3___services___campaign_experiment_service_pb2___MutateCampaignExperimentResult: ...
    @property
    def campaign_extension_setting_result(
        self,
    ) -> google___ads___googleads___v3___services___campaign_extension_setting_service_pb2___MutateCampaignExtensionSettingResult: ...
    @property
    def campaign_feed_result(
        self,
    ) -> google___ads___googleads___v3___services___campaign_feed_service_pb2___MutateCampaignFeedResult: ...
    @property
    def campaign_label_result(
        self,
    ) -> google___ads___googleads___v3___services___campaign_label_service_pb2___MutateCampaignLabelResult: ...
    @property
    def campaign_result(
        self,
    ) -> google___ads___googleads___v3___services___campaign_service_pb2___MutateCampaignResult: ...
    @property
    def campaign_shared_set_result(
        self,
    ) -> google___ads___googleads___v3___services___campaign_shared_set_service_pb2___MutateCampaignSharedSetResult: ...
    @property
    def conversion_action_result(
        self,
    ) -> google___ads___googleads___v3___services___conversion_action_service_pb2___MutateConversionActionResult: ...
    @property
    def customer_extension_setting_result(
        self,
    ) -> google___ads___googleads___v3___services___customer_extension_setting_service_pb2___MutateCustomerExtensionSettingResult: ...
    @property
    def customer_feed_result(
        self,
    ) -> google___ads___googleads___v3___services___customer_feed_service_pb2___MutateCustomerFeedResult: ...
    @property
    def customer_label_result(
        self,
    ) -> google___ads___googleads___v3___services___customer_label_service_pb2___MutateCustomerLabelResult: ...
    @property
    def customer_negative_criterion_result(
        self,
    ) -> google___ads___googleads___v3___services___customer_negative_criterion_service_pb2___MutateCustomerNegativeCriteriaResult: ...
    @property
    def customer_result(
        self,
    ) -> google___ads___googleads___v3___services___customer_service_pb2___MutateCustomerResult: ...
    @property
    def extension_feed_item_result(
        self,
    ) -> google___ads___googleads___v3___services___extension_feed_item_service_pb2___MutateExtensionFeedItemResult: ...
    @property
    def feed_item_result(
        self,
    ) -> google___ads___googleads___v3___services___feed_item_service_pb2___MutateFeedItemResult: ...
    @property
    def feed_item_target_result(
        self,
    ) -> google___ads___googleads___v3___services___feed_item_target_service_pb2___MutateFeedItemTargetResult: ...
    @property
    def feed_mapping_result(
        self,
    ) -> google___ads___googleads___v3___services___feed_mapping_service_pb2___MutateFeedMappingResult: ...
    @property
    def feed_result(
        self,
    ) -> google___ads___googleads___v3___services___feed_service_pb2___MutateFeedResult: ...
    @property
    def label_result(
        self,
    ) -> google___ads___googleads___v3___services___label_service_pb2___MutateLabelResult: ...
    @property
    def media_file_result(
        self,
    ) -> google___ads___googleads___v3___services___media_file_service_pb2___MutateMediaFileResult: ...
    @property
    def remarketing_action_result(
        self,
    ) -> google___ads___googleads___v3___services___remarketing_action_service_pb2___MutateRemarketingActionResult: ...
    @property
    def shared_criterion_result(
        self,
    ) -> google___ads___googleads___v3___services___shared_criterion_service_pb2___MutateSharedCriterionResult: ...
    @property
    def shared_set_result(
        self,
    ) -> google___ads___googleads___v3___services___shared_set_service_pb2___MutateSharedSetResult: ...
    @property
    def user_list_result(
        self,
    ) -> google___ads___googleads___v3___services___user_list_service_pb2___MutateUserListResult: ...
    def __init__(
        self,
        *,
        ad_group_ad_label_result: typing___Optional[
            google___ads___googleads___v3___services___ad_group_ad_label_service_pb2___MutateAdGroupAdLabelResult
        ] = None,
        ad_group_ad_result: typing___Optional[
            google___ads___googleads___v3___services___ad_group_ad_service_pb2___MutateAdGroupAdResult
        ] = None,
        ad_group_bid_modifier_result: typing___Optional[
            google___ads___googleads___v3___services___ad_group_bid_modifier_service_pb2___MutateAdGroupBidModifierResult
        ] = None,
        ad_group_criterion_label_result: typing___Optional[
            google___ads___googleads___v3___services___ad_group_criterion_label_service_pb2___MutateAdGroupCriterionLabelResult
        ] = None,
        ad_group_criterion_result: typing___Optional[
            google___ads___googleads___v3___services___ad_group_criterion_service_pb2___MutateAdGroupCriterionResult
        ] = None,
        ad_group_extension_setting_result: typing___Optional[
            google___ads___googleads___v3___services___ad_group_extension_setting_service_pb2___MutateAdGroupExtensionSettingResult
        ] = None,
        ad_group_feed_result: typing___Optional[
            google___ads___googleads___v3___services___ad_group_feed_service_pb2___MutateAdGroupFeedResult
        ] = None,
        ad_group_label_result: typing___Optional[
            google___ads___googleads___v3___services___ad_group_label_service_pb2___MutateAdGroupLabelResult
        ] = None,
        ad_group_result: typing___Optional[
            google___ads___googleads___v3___services___ad_group_service_pb2___MutateAdGroupResult
        ] = None,
        ad_parameter_result: typing___Optional[
            google___ads___googleads___v3___services___ad_parameter_service_pb2___MutateAdParameterResult
        ] = None,
        ad_result: typing___Optional[
            google___ads___googleads___v3___services___ad_service_pb2___MutateAdResult
        ] = None,
        asset_result: typing___Optional[
            google___ads___googleads___v3___services___asset_service_pb2___MutateAssetResult
        ] = None,
        bidding_strategy_result: typing___Optional[
            google___ads___googleads___v3___services___bidding_strategy_service_pb2___MutateBiddingStrategyResult
        ] = None,
        campaign_bid_modifier_result: typing___Optional[
            google___ads___googleads___v3___services___campaign_bid_modifier_service_pb2___MutateCampaignBidModifierResult
        ] = None,
        campaign_budget_result: typing___Optional[
            google___ads___googleads___v3___services___campaign_budget_service_pb2___MutateCampaignBudgetResult
        ] = None,
        campaign_criterion_result: typing___Optional[
            google___ads___googleads___v3___services___campaign_criterion_service_pb2___MutateCampaignCriterionResult
        ] = None,
        campaign_draft_result: typing___Optional[
            google___ads___googleads___v3___services___campaign_draft_service_pb2___MutateCampaignDraftResult
        ] = None,
        campaign_experiment_result: typing___Optional[
            google___ads___googleads___v3___services___campaign_experiment_service_pb2___MutateCampaignExperimentResult
        ] = None,
        campaign_extension_setting_result: typing___Optional[
            google___ads___googleads___v3___services___campaign_extension_setting_service_pb2___MutateCampaignExtensionSettingResult
        ] = None,
        campaign_feed_result: typing___Optional[
            google___ads___googleads___v3___services___campaign_feed_service_pb2___MutateCampaignFeedResult
        ] = None,
        campaign_label_result: typing___Optional[
            google___ads___googleads___v3___services___campaign_label_service_pb2___MutateCampaignLabelResult
        ] = None,
        campaign_result: typing___Optional[
            google___ads___googleads___v3___services___campaign_service_pb2___MutateCampaignResult
        ] = None,
        campaign_shared_set_result: typing___Optional[
            google___ads___googleads___v3___services___campaign_shared_set_service_pb2___MutateCampaignSharedSetResult
        ] = None,
        conversion_action_result: typing___Optional[
            google___ads___googleads___v3___services___conversion_action_service_pb2___MutateConversionActionResult
        ] = None,
        customer_extension_setting_result: typing___Optional[
            google___ads___googleads___v3___services___customer_extension_setting_service_pb2___MutateCustomerExtensionSettingResult
        ] = None,
        customer_feed_result: typing___Optional[
            google___ads___googleads___v3___services___customer_feed_service_pb2___MutateCustomerFeedResult
        ] = None,
        customer_label_result: typing___Optional[
            google___ads___googleads___v3___services___customer_label_service_pb2___MutateCustomerLabelResult
        ] = None,
        customer_negative_criterion_result: typing___Optional[
            google___ads___googleads___v3___services___customer_negative_criterion_service_pb2___MutateCustomerNegativeCriteriaResult
        ] = None,
        customer_result: typing___Optional[
            google___ads___googleads___v3___services___customer_service_pb2___MutateCustomerResult
        ] = None,
        extension_feed_item_result: typing___Optional[
            google___ads___googleads___v3___services___extension_feed_item_service_pb2___MutateExtensionFeedItemResult
        ] = None,
        feed_item_result: typing___Optional[
            google___ads___googleads___v3___services___feed_item_service_pb2___MutateFeedItemResult
        ] = None,
        feed_item_target_result: typing___Optional[
            google___ads___googleads___v3___services___feed_item_target_service_pb2___MutateFeedItemTargetResult
        ] = None,
        feed_mapping_result: typing___Optional[
            google___ads___googleads___v3___services___feed_mapping_service_pb2___MutateFeedMappingResult
        ] = None,
        feed_result: typing___Optional[
            google___ads___googleads___v3___services___feed_service_pb2___MutateFeedResult
        ] = None,
        label_result: typing___Optional[
            google___ads___googleads___v3___services___label_service_pb2___MutateLabelResult
        ] = None,
        media_file_result: typing___Optional[
            google___ads___googleads___v3___services___media_file_service_pb2___MutateMediaFileResult
        ] = None,
        remarketing_action_result: typing___Optional[
            google___ads___googleads___v3___services___remarketing_action_service_pb2___MutateRemarketingActionResult
        ] = None,
        shared_criterion_result: typing___Optional[
            google___ads___googleads___v3___services___shared_criterion_service_pb2___MutateSharedCriterionResult
        ] = None,
        shared_set_result: typing___Optional[
            google___ads___googleads___v3___services___shared_set_service_pb2___MutateSharedSetResult
        ] = None,
        user_list_result: typing___Optional[
            google___ads___googleads___v3___services___user_list_service_pb2___MutateUserListResult
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group_ad_label_result",
            b"ad_group_ad_label_result",
            "ad_group_ad_result",
            b"ad_group_ad_result",
            "ad_group_bid_modifier_result",
            b"ad_group_bid_modifier_result",
            "ad_group_criterion_label_result",
            b"ad_group_criterion_label_result",
            "ad_group_criterion_result",
            b"ad_group_criterion_result",
            "ad_group_extension_setting_result",
            b"ad_group_extension_setting_result",
            "ad_group_feed_result",
            b"ad_group_feed_result",
            "ad_group_label_result",
            b"ad_group_label_result",
            "ad_group_result",
            b"ad_group_result",
            "ad_parameter_result",
            b"ad_parameter_result",
            "ad_result",
            b"ad_result",
            "asset_result",
            b"asset_result",
            "bidding_strategy_result",
            b"bidding_strategy_result",
            "campaign_bid_modifier_result",
            b"campaign_bid_modifier_result",
            "campaign_budget_result",
            b"campaign_budget_result",
            "campaign_criterion_result",
            b"campaign_criterion_result",
            "campaign_draft_result",
            b"campaign_draft_result",
            "campaign_experiment_result",
            b"campaign_experiment_result",
            "campaign_extension_setting_result",
            b"campaign_extension_setting_result",
            "campaign_feed_result",
            b"campaign_feed_result",
            "campaign_label_result",
            b"campaign_label_result",
            "campaign_result",
            b"campaign_result",
            "campaign_shared_set_result",
            b"campaign_shared_set_result",
            "conversion_action_result",
            b"conversion_action_result",
            "customer_extension_setting_result",
            b"customer_extension_setting_result",
            "customer_feed_result",
            b"customer_feed_result",
            "customer_label_result",
            b"customer_label_result",
            "customer_negative_criterion_result",
            b"customer_negative_criterion_result",
            "customer_result",
            b"customer_result",
            "extension_feed_item_result",
            b"extension_feed_item_result",
            "feed_item_result",
            b"feed_item_result",
            "feed_item_target_result",
            b"feed_item_target_result",
            "feed_mapping_result",
            b"feed_mapping_result",
            "feed_result",
            b"feed_result",
            "label_result",
            b"label_result",
            "media_file_result",
            b"media_file_result",
            "remarketing_action_result",
            b"remarketing_action_result",
            "response",
            b"response",
            "shared_criterion_result",
            b"shared_criterion_result",
            "shared_set_result",
            b"shared_set_result",
            "user_list_result",
            b"user_list_result",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group_ad_label_result",
            b"ad_group_ad_label_result",
            "ad_group_ad_result",
            b"ad_group_ad_result",
            "ad_group_bid_modifier_result",
            b"ad_group_bid_modifier_result",
            "ad_group_criterion_label_result",
            b"ad_group_criterion_label_result",
            "ad_group_criterion_result",
            b"ad_group_criterion_result",
            "ad_group_extension_setting_result",
            b"ad_group_extension_setting_result",
            "ad_group_feed_result",
            b"ad_group_feed_result",
            "ad_group_label_result",
            b"ad_group_label_result",
            "ad_group_result",
            b"ad_group_result",
            "ad_parameter_result",
            b"ad_parameter_result",
            "ad_result",
            b"ad_result",
            "asset_result",
            b"asset_result",
            "bidding_strategy_result",
            b"bidding_strategy_result",
            "campaign_bid_modifier_result",
            b"campaign_bid_modifier_result",
            "campaign_budget_result",
            b"campaign_budget_result",
            "campaign_criterion_result",
            b"campaign_criterion_result",
            "campaign_draft_result",
            b"campaign_draft_result",
            "campaign_experiment_result",
            b"campaign_experiment_result",
            "campaign_extension_setting_result",
            b"campaign_extension_setting_result",
            "campaign_feed_result",
            b"campaign_feed_result",
            "campaign_label_result",
            b"campaign_label_result",
            "campaign_result",
            b"campaign_result",
            "campaign_shared_set_result",
            b"campaign_shared_set_result",
            "conversion_action_result",
            b"conversion_action_result",
            "customer_extension_setting_result",
            b"customer_extension_setting_result",
            "customer_feed_result",
            b"customer_feed_result",
            "customer_label_result",
            b"customer_label_result",
            "customer_negative_criterion_result",
            b"customer_negative_criterion_result",
            "customer_result",
            b"customer_result",
            "extension_feed_item_result",
            b"extension_feed_item_result",
            "feed_item_result",
            b"feed_item_result",
            "feed_item_target_result",
            b"feed_item_target_result",
            "feed_mapping_result",
            b"feed_mapping_result",
            "feed_result",
            b"feed_result",
            "label_result",
            b"label_result",
            "media_file_result",
            b"media_file_result",
            "remarketing_action_result",
            b"remarketing_action_result",
            "response",
            b"response",
            "shared_criterion_result",
            b"shared_criterion_result",
            "shared_set_result",
            b"shared_set_result",
            "user_list_result",
            b"user_list_result",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["response", b"response"]
    ) -> typing_extensions___Literal[
        "ad_group_ad_label_result",
        "ad_group_ad_result",
        "ad_group_bid_modifier_result",
        "ad_group_criterion_label_result",
        "ad_group_criterion_result",
        "ad_group_extension_setting_result",
        "ad_group_feed_result",
        "ad_group_label_result",
        "ad_group_result",
        "ad_parameter_result",
        "ad_result",
        "asset_result",
        "bidding_strategy_result",
        "campaign_bid_modifier_result",
        "campaign_budget_result",
        "campaign_criterion_result",
        "campaign_draft_result",
        "campaign_experiment_result",
        "campaign_extension_setting_result",
        "campaign_feed_result",
        "campaign_label_result",
        "campaign_result",
        "campaign_shared_set_result",
        "conversion_action_result",
        "customer_extension_setting_result",
        "customer_feed_result",
        "customer_label_result",
        "customer_negative_criterion_result",
        "customer_result",
        "extension_feed_item_result",
        "feed_item_result",
        "feed_item_target_result",
        "feed_mapping_result",
        "feed_result",
        "label_result",
        "media_file_result",
        "remarketing_action_result",
        "shared_criterion_result",
        "shared_set_result",
        "user_list_result",
    ]: ...

type___MutateOperationResponse = MutateOperationResponse



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdGroupErrorValue = typing___NewType("AdGroupErrorValue", builtin___int)
    type___AdGroupErrorValue = AdGroupErrorValue
    AdGroupError: _AdGroupError
    class _AdGroupError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdGroupErrorEnum.AdGroupErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 0)
        UNKNOWN = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 1)
        DUPLICATE_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 2)
        INVALID_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 3)
        ADVERTISER_NOT_ON_CONTENT_NETWORK = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 5
        )
        BID_TOO_BIG = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 6)
        BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 7
        )
        MISSING_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 8)
        ADGROUP_LABEL_DOES_NOT_EXIST = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 9
        )
        ADGROUP_LABEL_ALREADY_EXISTS = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 10
        )
        INVALID_CONTENT_BID_CRITERION_TYPE_GROUP = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 11
        )
        AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 12
        )
        ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 13
        )
        CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 14
        )
        PROMOTED_HOTEL_AD_GROUPS_NOT_AVAILABLE_FOR_CUSTOMER = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 15
        )
    UNSPECIFIED = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 0)
    UNKNOWN = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 1)
    DUPLICATE_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 2)
    INVALID_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 3)
    ADVERTISER_NOT_ON_CONTENT_NETWORK = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 5
    )
    BID_TOO_BIG = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 6)
    BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 7
    )
    MISSING_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 8)
    ADGROUP_LABEL_DOES_NOT_EXIST = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 9)
    ADGROUP_LABEL_ALREADY_EXISTS = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 10)
    INVALID_CONTENT_BID_CRITERION_TYPE_GROUP = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 11
    )
    AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 12
    )
    ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 13
    )
    CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 14
    )
    PROMOTED_HOTEL_AD_GROUPS_NOT_AVAILABLE_FOR_CUSTOMER = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 15
    )
    type___AdGroupError = AdGroupError
    def __init__(self,) -> None: ...

type___AdGroupErrorEnum = AdGroupErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AssetPerformanceLabelEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AssetPerformanceLabelValue = typing___NewType(
        "AssetPerformanceLabelValue", builtin___int
    )
    type___AssetPerformanceLabelValue = AssetPerformanceLabelValue
    AssetPerformanceLabel: _AssetPerformanceLabel
    class _AssetPerformanceLabel(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AssetPerformanceLabelEnum.AssetPerformanceLabelValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 0
        )
        UNKNOWN = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 1)
        PENDING = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 2)
        LEARNING = typing___cast(
            AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 3
        )
        LOW = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 4)
        GOOD = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 5)
        BEST = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 6)
    UNSPECIFIED = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 0)
    UNKNOWN = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 1)
    PENDING = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 2)
    LEARNING = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 3)
    LOW = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 4)
    GOOD = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 5)
    BEST = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 6)
    type___AssetPerformanceLabel = AssetPerformanceLabel
    def __init__(self,) -> None: ...

type___AssetPerformanceLabelEnum = AssetPerformanceLabelEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.offline_user_data_pb2 import (
    CustomerMatchUserListMetadata as google___ads___googleads___v3___common___offline_user_data_pb2___CustomerMatchUserListMetadata,
    StoreSalesMetadata as google___ads___googleads___v3___common___offline_user_data_pb2___StoreSalesMetadata,
)
from google.ads.google_ads.v3.proto.enums.offline_user_data_job_failure_reason_pb2 import (
    OfflineUserDataJobFailureReasonEnum as google___ads___googleads___v3___enums___offline_user_data_job_failure_reason_pb2___OfflineUserDataJobFailureReasonEnum,
)
from google.ads.google_ads.v3.proto.enums.offline_user_data_job_status_pb2 import (
    OfflineUserDataJobStatusEnum as google___ads___googleads___v3___enums___offline_user_data_job_status_pb2___OfflineUserDataJobStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.offline_user_data_job_type_pb2 import (
    OfflineUserDataJobTypeEnum as google___ads___googleads___v3___enums___offline_user_data_job_type_pb2___OfflineUserDataJobTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class OfflineUserDataJob(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    type: google___ads___googleads___v3___enums___offline_user_data_job_type_pb2___OfflineUserDataJobTypeEnum.OfflineUserDataJobTypeValue = ...
    status: google___ads___googleads___v3___enums___offline_user_data_job_status_pb2___OfflineUserDataJobStatusEnum.OfflineUserDataJobStatusValue = ...
    failure_reason: google___ads___googleads___v3___enums___offline_user_data_job_failure_reason_pb2___OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReasonValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def external_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def customer_match_user_list_metadata(
        self,
    ) -> google___ads___googleads___v3___common___offline_user_data_pb2___CustomerMatchUserListMetadata: ...
    @property
    def store_sales_metadata(
        self,
    ) -> google___ads___googleads___v3___common___offline_user_data_pb2___StoreSalesMetadata: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        external_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        type: typing___Optional[
            google___ads___googleads___v3___enums___offline_user_data_job_type_pb2___OfflineUserDataJobTypeEnum.OfflineUserDataJobTypeValue
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v3___enums___offline_user_data_job_status_pb2___OfflineUserDataJobStatusEnum.OfflineUserDataJobStatusValue
        ] = None,
        failure_reason: typing___Optional[
            google___ads___googleads___v3___enums___offline_user_data_job_failure_reason_pb2___OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReasonValue
        ] = None,
        customer_match_user_list_metadata: typing___Optional[
            google___ads___googleads___v3___common___offline_user_data_pb2___CustomerMatchUserListMetadata
        ] = None,
        store_sales_metadata: typing___Optional[
            google___ads___googleads___v3___common___offline_user_data_pb2___StoreSalesMetadata
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "external_id",
            b"external_id",
            "id",
            b"id",
            "metadata",
            b"metadata",
            "store_sales_metadata",
            b"store_sales_metadata",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "external_id",
            b"external_id",
            "failure_reason",
            b"failure_reason",
            "id",
            b"id",
            "metadata",
            b"metadata",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "store_sales_metadata",
            b"store_sales_metadata",
            "type",
            b"type",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["metadata", b"metadata"]
    ) -> typing_extensions___Literal[
        "customer_match_user_list_metadata", "store_sales_metadata"
    ]: ...

type___OfflineUserDataJob = OfflineUserDataJob



from typing import Any

class MediaFileServiceStub:
    GetMediaFile: Any = ...
    MutateMediaFiles: Any = ...
    def __init__(self, channel: Any) -> None: ...

class MediaFileServiceServicer:
    def GetMediaFile(self, request: Any, context: Any) -> None: ...
    def MutateMediaFiles(self, request: Any, context: Any) -> None: ...

def add_MediaFileServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DynamicSearchAdsSearchTermView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    @property
    def search_term(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def headline(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def landing_page(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def page_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def has_negative_keyword(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def has_matching_keyword(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def has_negative_url(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        search_term: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        headline: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        landing_page: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        page_url: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        has_negative_keyword: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        has_matching_keyword: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        has_negative_url: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "has_matching_keyword",
            b"has_matching_keyword",
            "has_negative_keyword",
            b"has_negative_keyword",
            "has_negative_url",
            b"has_negative_url",
            "headline",
            b"headline",
            "landing_page",
            b"landing_page",
            "page_url",
            b"page_url",
            "search_term",
            b"search_term",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "has_matching_keyword",
            b"has_matching_keyword",
            "has_negative_keyword",
            b"has_negative_keyword",
            "has_negative_url",
            b"has_negative_url",
            "headline",
            b"headline",
            "landing_page",
            b"landing_page",
            "page_url",
            b"page_url",
            "resource_name",
            b"resource_name",
            "search_term",
            b"search_term",
        ],
    ) -> None: ...

type___DynamicSearchAdsSearchTermView = DynamicSearchAdsSearchTermView



from typing import Any

class ShoppingPerformanceViewServiceStub:
    GetShoppingPerformanceView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ShoppingPerformanceViewServiceServicer:
    def GetShoppingPerformanceView(self, request: Any, context: Any) -> None: ...

def add_ShoppingPerformanceViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
